# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Color.Degenerate as Degenerate
import QT4Color.Globals as Globals
import PyOpenColorIO as OCIO
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Color.ColorTransforms import ClampRGBA as ClampRGBA, ConvertColorToUnits as ConvertColorToUnits, ConvertUnitsToColor as ConvertUnitsToColor
from typing import ClassVar, Set, Tuple

class LinearGradientWidget(PyQt5.QtWidgets.QWidget):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, mode, enableFilmlook, enableNoFilmlookColorSpace, parent, orientation: PyQt5.QtCore.Qt.Orientation = ...) -> None: ...
    def _LinearGradientWidget__componentToWindowPos(self, component): ...
    def _LinearGradientWidget__drawPointer(self, painter): ...
    def _LinearGradientWidget__emit(self, componentValue, final): ...
    def _LinearGradientWidget__getPointerColor(self): ...
    def _LinearGradientWidget__isPreselectionActive(self): ...
    def _LinearGradientWidget__isfinite(self, value): ...
    def _LinearGradientWidget__recomputeComponentValue(self): ...
    def _LinearGradientWidget__windowPosToComponent(self, posX, posY): ...
    def enterEvent(self, ev): ...
    def getColor(self): ...
    def getPickingColorspace(self): ...
    def leaveEvent(self, ev): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def mouseReleaseEvent(self, ev): ...
    def paintEvent(self, ev): ...
    def recomputeGradient(self): ...
    def resizeEvent(self, ev): ...
    def setColor(self, linearColor): ...
    def setFilmlookEnabled(self, enabled): ...
    def setMode(self, mode): ...
    def setNoFilmlookColorSpaceEnabled(self, enabled): ...
    def setReadOnly(self, value): ...
    def sizeHint(self): ...
    def sizePolicy(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.GenericAssign import GenericAssign as GenericAssign
from _typeshed import Incomplete
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class CameraClippingPlaneEdit(GenericAssign):
    def __init__(self) -> None: ...
    def _filterAttrList(self, graphState: NodegraphAPI.GraphState, attrList): ...
    def _getExtraAttrs(self, frameTime): ...
    def _getStaticAttrHintsForIncomingSceneQuery(self, attrPath): ...
    def addParameterHints(self, attrName, inputDict): ...
    def canOverride(self, attrName): ...
    def setOverride(self, path, attrName, time, attrData, attrType: Incomplete | None = ..., attrTupleSize: Incomplete | None = ..., makeEmptyGroup: bool = ..., groupInherit: bool = ..., index: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI.NetworkMaterial
import PyXmlIO as PyXmlIO
import Nodes3DAPI.ShadingNodeBase as ShadingNodeBase
from Nodes3DAPI.CreateUtil import BuildChild as BuildChild
from Nodes3DAPI.NetworkMaterial import NetworkMaterialNode as NetworkMaterialNode
from Nodes3DAPI.ShadingNodeUtil import ReportError as ReportError
from _typeshed import Incomplete
from typing import Set, Tuple

_DefaultConnectionParamXML: str
_DefaultDisconnectionParamXML: str
_ExtraHints: dict
_Parameter_XML: str

class NetworkMaterialSplice(Nodes3DAPI.NetworkMaterial.NetworkMaterialNode):
    def __init__(self) -> None: ...
    def AddGroup(self, param): ...
    def DeleteGroup(self, index, param): ...
    def ReorderGroup(self, index, newIndex, param): ...
    def _NetworkMaterialSplice__buildOpArgs(self, graphState: NodegraphAPI.GraphState): ...
    def _areInputsAndParametersDirty(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, visitedState, reset: bool = ...): ...
    def _getOp(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, visitedState, transaction): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def getNetworkAttr(self, includeInsertion: bool = ..., addedNameSet: Incomplete | None = ...): ...
    def getScenegraphLocation(self, frameTime: int = ...): ...
    def isResetPossible(self): ...
    def validateConnection(self, otherOutPort, myInPort, errorMessages: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from . import Util as Util
from typing import Any, Set, Tuple, overload

NO_OP: str

class Geolib:
    def __init__(self) -> None: ...
    def createRuntime(self, *args, **kwargs): ...
    def setPluginPath(self, arg0: list[str]) -> None: ...

class GeolibRuntime:
    def __init__(self, *args, **kwargs) -> None: ...
    def EndProfilingSession(self, outputFile: str = ...) -> None: ...
    def IsProfilingSession(self) -> bool: ...
    def StartProfilingSession(self) -> None: ...
    def _sendMessageInternal(self, arg0: object) -> Any: ...
    @overload
    def commit(self, txn: GeolibRuntimeTransaction) -> int: ...
    @overload
    def commit(self, txns: list[GeolibRuntimeTransaction]) -> int: ...
    def createTransaction(self) -> GeolibRuntimeTransaction: ...
    def describeOp(self, opType: str) -> PyFnAttribute.GroupAttribute: ...
    def evict(self, primaryPathToKeep: str) -> None: ...
    def flushCaches(self) -> None: ...
    def getLatestCommitId(self) -> int: ...
    def getOpFromOpId(self, opId: int) -> GeolibRuntimeOp: ...
    def getOptions(self) -> PyFnAttribute.Attribute: ...
    def getRegisteredOpTypes(self) -> PyFnAttribute.StringAttribute: ...
    def getRootLocationPath(self) -> str: ...
    def isProcessing(self) -> bool: ...
    def isValidOp(self, opId: int) -> bool: ...
    def setOptions(self, options: PyFnAttribute.Attribute) -> None: ...

class GeolibRuntimeClient:
    def __init__(self, *args, **kwargs) -> None: ...
    def cookLocation(self, locationPath: str) -> LocationData: ...
    def getActiveLocations(self, rootLocationPath: str) -> list[str]: ...
    def getCachedLocation(self, locationPath: str) -> Any: ...
    def getLocationEvents(self, maxEvents: int = ...) -> tuple: ...
    def getOp(self) -> GeolibRuntimeOp: ...
    def getOpenLocations(self, rootLocationPath: str) -> list[str]: ...
    def hasLocationEvents(self) -> bool: ...
    def interruptOpenRecursive(self) -> None: ...
    def isAllOpen(self) -> bool: ...
    def isEventCachingEnabled(self) -> bool: ...
    def isLocationActive(self, locationPath: str) -> bool: ...
    def isLocationDataCurrent(self, locationPath: str, commitId: int = ...) -> bool: ...
    def isLocationOpen(self, locationPath: str) -> bool: ...
    def setAllOpen(self, allOpen: bool) -> None: ...
    def setEventCachingEnabled(self, enabled: bool = ...) -> None: ...
    def setLocationsActive(self, locationPaths: list[str]) -> None: ...
    def setLocationsClosed(self, locationPaths: list[str]) -> None: ...
    def setLocationsClosedRecursive(self, locationPaths: list[str]) -> None: ...
    def setLocationsInactive(self, locationPaths: list[str]) -> None: ...
    def setLocationsOpen(self, locationPaths: list[str]) -> None: ...
    def setLocationsOpenRecursive(self, locationPaths: list[str], stopTypes: list[str] = ...) -> None: ...

class GeolibRuntimeOp:
    def __init__(self, *args, **kwargs) -> None: ...
    def getInputs(self) -> tuple: ...
    def getNodeName(self) -> str: ...
    def getNodeType(self) -> str: ...
    def getOpArgs(self) -> tuple: ...
    def getOpId(self) -> int: ...
    def getTag(self) -> str: ...
    def serializeToFile(self, filepath: str) -> bool: ...

class GeolibRuntimeTransaction:
    def __init__(self, *args, **kwargs) -> None: ...
    def createClient(self, *args, **kwargs): ...
    def createOp(self) -> GeolibRuntimeOp: ...
    def deserializeOpsFromFile(self, filepath: str) -> GeolibRuntimeOp: ...
    def setClientOp(self, client, op: GeolibRuntimeOp) -> None: ...
    def setNodeName(self, op: GeolibRuntimeOp, nodeName: str) -> None: ...
    def setNodeType(self, op: GeolibRuntimeOp, nodeType: str) -> None: ...
    def setOpArgs(self, op: GeolibRuntimeOp, opType: str, opArgs: PyFnAttribute.Attribute) -> None: ...
    def setOpInputs(self, op: GeolibRuntimeOp, inputs: list[GeolibRuntimeOp]) -> None: ...
    def setTag(self, op: GeolibRuntimeOp, tag: str) -> None: ...

class LocationData:
    def __init__(self, *args, **kwargs) -> None: ...
    def doesLocationExist(self) -> bool: ...
    def getAttrs(self) -> PyFnAttribute.GroupAttribute: ...
    def getAttrsHash(self) -> str: ...
    def getHash(self) -> str: ...
    def getPotentialChildren(self) -> list: ...
    def getPotentialChildrenAttr(self) -> PyFnAttribute.StringAttribute: ...
    def getPotentialChildrenHash(self) -> str: ...

class LocationEvent:
    def __init__(self, *args, **kwargs) -> None: ...
    def getLocationData(self) -> Any: ...
    def getLocationPath(self) -> str: ...
    def getLocationPathAttr(self) -> PyFnAttribute.StringAttribute: ...
    def hasLocationData(self) -> bool: ...
    def hasOpenChange(self) -> bool: ...
    @overload
    def isLocationDataCurrent(self) -> bool: ...
    @overload
    def isLocationDataCurrent(self) -> Any: ...
    def isOpen(self) -> bool: ...

def GetRegisteredRuntimeInstance(*args, **kwargs): ...
def RegisterRuntimeInstance(runtime, key: str = ...) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI.TransformUtil as TransformUtil
from Nodes3DAPI.AbstractTransform import AT as AT, AbstractTransform as AbstractTransform
from Nodes3DAPI.PrimitiveCreate import PrimitiveCreate
from _typeshed import Incomplete
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str
_resource_path: str
_root_path: str

class PrimitiveCreate(AbstractTransform):
    def __init__(self, primitiveType: Incomplete | None = ...) -> None: ...
    def _PrimitiveCreate__initName(self): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def customReset(self): ...
    def getScenegraphLocation(self): ...

class TeapotCreate(PrimitiveCreate):
    def __init__(self) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import UI4 as UI4
import Utils as Utils
from typing import Set, Tuple

def CreateManipulatorLayer(policy, *args, **kwargs): ...
def GetAnimationPathsEnabled(): ...
def GetManipulatedPolicies(): ...
def GetManipulatorPolicy(param): ...
def IsManipulatorEnabled(param): ...
def RegisterManipulatorLayer(nodeType, paramMatchString, widgetName): ...
def SetAnimationPathsEnabled(enabled): ...
def SetManipulatorEnabled(param, isEnabled): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
from typing import Set, Tuple

class Delegate:
    def acceptsDrop(self, targetNode, event): ...
    def addToContextMenu(self, targetNode, menu): ...
    def addToNodeSpecificShelfEnvironment(self, targetNode, editor, envDict): ...
    def getLastContextMenuNode(self): ...
    def processDrop(self, targetNode, event): ...

def AcceptsDrop(targetNode, event): ...
def AddToContextMenu(targetNode, menu): ...
def AddToNodeSpecificShelfEnvironment(targetNode, editor, envDict): ...
def ProcessDrop(targetNode, event): ...
def RegisterDelegate(nodeType, delegate): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import RenderingAPI_cmodule.RenderOutputLocation as RenderOutputLocation
import RenderingAPI_cmodule.Renderer as Renderer
import RenderingAPI_cmodule.RendererInfo as RendererInfo
import RenderingAPI_cmodule as RenderingAPI_cmodule
import Utils as Utils
from . import RenderOutputs as RenderOutputs, RenderPlugins as RenderPlugins
from typing import Set, Tuple

class RenderStartupError(AttributeError): ...

def __FlushPluginCaches(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtGui as QtGui
import UI4.Widgets.SceneGraphView.SceneGraphViewColumn
from typing import ClassVar, Set, Tuple

class ColumnPreset:
    def __init__(self) -> None: ...
    def activate(self): ...
    def addHidden(self, columnOrSet: BaseSceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.BaseSceneGraphColumn]): ...
    def addShown(self, columnOrSet: BaseSceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.BaseSceneGraphColumn]): ...
    def addToggled(self, columnOrSet: BaseSceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.BaseSceneGraphColumn]): ...
    def removeHidden(self, columnOrSet: BaseSceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.BaseSceneGraphColumn]): ...
    def removeShown(self, columnOrSet: BaseSceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.BaseSceneGraphColumn]): ...
    def removeToggled(self, columnOrSet: BaseSceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.BaseSceneGraphColumn]): ...

class ColumnPresetManager:
    class ShortcutMode:
        Toggle: ClassVar[int] = ...
        Unique: ClassVar[int] = ...
        @classmethod
        def getValidShortcutModes(cls) -> list[int]: ...
    def __init__(self) -> None: ...
    def addColumnSetShortcut(self, columnSet: SceneGraphColumnSet, shortcut: str | None | int | QKeySequence): ...
    def addPreset(self, shortcut: str | None | int | QKeySequence) -> ColumnPreset: ...
    def processKeyPressEvent(self, event: PyQt5.QtGui.QKeyEvent) -> bool: ...
    def removeColumnSetShortcut(self, columnSet: SceneGraphColumnSet, shortcut: str | None | int | QKeySequence): ...
    def removeColumnSetShortcuts(self, columnSet: SceneGraphColumnSet): ...
    def removePreset(self, preset: ColumnPreset): ...
    def setShortcutMode(self, shortcutMode: int): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Any, Set, Tuple

class RenderOutputLocationPlugin:
    def __init__(self, *args, **kwargs) -> None: ...
    def computeFilePath(self, outputAttrs: dict, locationAttrs: dict, renderSettingsAttr: dict, imageInfo: dict, makeVersionTemplate: bool) -> str: ...
    def computeLocation(self, outputAttrs: dict, locationAttrs: dict, renderSettingsAttr: dict, imageInfo: dict) -> str: ...
    def getLocationSettingsAttr(self, outputType: str, incomingOutputAttr: PyFnAttribute.GroupAttribute) -> PyFnAttribute.GroupAttribute: ...

def GetPlugin(pluginName: str) -> Any: ...
def GetPluginNames() -> list[str]: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.SceneGraphView.SceneGraphViewColumn import SceneGraphColumnTitle as SceneGraphColumnTitle
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class HorizontalHeaderView(PyQt5.QtWidgets.QHeaderView):
    ClickStyleRole: ClassVar[int] = ...
    HeaderTitleIconRole: ClassVar[int] = ...
    IsToggledOnFunctionRole: ClassVar[int] = ...
    SectionClickableRole: ClassVar[int] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _HorizontalHeaderView__getLogicalIndexes(self, pointerX: int) -> tuple[int, int] | None: ...
    def _HorizontalHeaderView__on_activePopupWidget_hide(self): ...
    def _HorizontalHeaderView__on_resizeAllToContentsAction_triggered(self): ...
    def _HorizontalHeaderView__on_resizeToContentsAction_triggered(self): ...
    def contextMenuEvent(self, contextMenuEvent: PyQt5.QtGui.QContextMenuEvent): ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def mouseDoubleClickEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def mouseMoveEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def mousePressEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def mouseReleaseEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def paintSection(self, painter: PyQt5.QtGui.QPainter, rect: PyQt5.QtCore.QRect, logicalIndex: int): ...
    def resizeSection(self, logicalIndex: int, size: int): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import UI4.FormMaster.Editors.Number as Number
import QT4FormWidgets as QT4FormWidgets
import PyResolutionTableFn as ResolutionTable
import UI4.FormMaster.Editors.Number
import Utils as Utils
from typing import Set, Tuple

class AdjustMaxToDisplayWindowNumberFormWidget(UI4.FormMaster.Editors.Number.KatanaNumberFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _AdjustMaxToDisplayWindowNumberFormWidget__loadBeginCB(self, args): ...
    def _AdjustMaxToDisplayWindowNumberFormWidget__loadEndCB(self, args): ...
    def _AdjustMaxToDisplayWindowNumberFormWidget__updateMax(self): ...
    def _AdjustMaxToDisplayWindowNumberFormWidget__updateMaxCB(self, args): ...
    def _freeze(self): ...
    def _thaw(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Callbacks as Callbacks
import NodegraphAPI as NodegraphAPI
import Utils as Utils
from typing import Set, Tuple

def GetParamNameForNodeType(nodeType): ...
def IsNodeNameFromParam(nodeType): ...
def RegisterNodeNameFromParam(nodeType: str, paramName: str, capitalize: bool = ..., synchronize: bool = ...): ...
def UpdateNodeNameFromParam(node: NodegraphAPI.Node): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as FW
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from PyUtilModule.VirtualKatana import Decorators as Decorators, FormMaster as FormMaster, ScenegraphManager as ScenegraphManager, Widgets as Widgets
from UI4.FormMaster.FnAttributePolicy import AttributePolicy as AttributePolicy
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from typing import Set, Tuple

class AttributesTab(BaseTab):
    def __init__(self, parent) -> None: ...
    def _AttributesTab__activePathPopupClicked(self): ...
    def _AttributesTab__activePathPopupSelected(self, path): ...
    def _AttributesTab__addImplicitResolvers(self, txn, opId, viewedNode): ...
    def _AttributesTab__buildOrUpdate(self, attrs): ...
    def _AttributesTab__clear(self): ...
    def _AttributesTab__findAttributesActionCallback(self): ...
    def _AttributesTab__getAttrMetaDict(self, gb, attrs): ...
    def _AttributesTab__iconMenuAboutToShow(self): ...
    def _AttributesTab__iconMousePress(self, event): ...
    def _AttributesTab__iconStartDrag(self): ...
    def _AttributesTab__idle(self, *args, **kwds): ...
    def _AttributesTab__nodeSetViewed(self, args): ...
    def _AttributesTab__on_renderingAPI_flushPluginCaches(self): ...
    def _AttributesTab__selectionChanged(self, args): ...
    def _AttributesTab__setTerminalOpInput(self, opInput, txn): ...
    def _AttributesTab__terminalOpCallback(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, op, transaction): ...
    def _AttributesTab__updateActiveLocation(self, newLocation): ...
    def _AttributesTab__updateTypeIcon(self, typeStr): ...
    def customEvent(self, event): ...
    @staticmethod
    def registerKeyboardShortcuts(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.ValuePolicy
import QT4FormWidgets.ValuePolicy as ValuePolicy
from _typeshed import Incomplete
from typing import Set, Tuple

class ValuePolicyAdapter(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, alias, policyMap, parent: Incomplete | None = ...) -> None: ...
    def getArrayChild(self, index): ...
    def getArraySize(self): ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getNumChildren(self): ...
    def getType(self): ...
    def getValueState(self): ...
    def getWidgetHints(self): ...
    def isLocked(self): ...
    def removeArrayChild(self, index): ...
    def reorderArrayChild(self, oldIndex, newIndex): ...
    def setWidgetHints(self, hints): ...

class ValuePolicyAlias(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, alias, valuePolicy, parent: Incomplete | None = ...) -> None: ...
    def _AbstractValuePolicy__parentNameChanged(self, *args, **kwargs): ...
    def _appendToContextMenu(self, *args, **kwargs): ...
    def _appendToStateMenu(self, *args, **kwargs): ...
    def _appendToWrenchMenu(self, *args, **kwargs): ...
    def _childStateChange(self, *args, **kwargs): ...
    def _childStateReset(self, *args, **kwargs): ...
    def _closeButtonClicked(self, *args, **kwargs): ...
    def _customizeWrenchButton(self, *args, **kwargs): ...
    def _freeze(self, *args, **kwargs): ...
    def _handleValuePolicyChange(self, *args, **kwargs): ...
    def _potentialFreezeChange(self, *args, **kwargs): ...
    def _propagateNameChange(self, *args, **kwargs): ...
    def _propagateStateChange(self, visitedParents: set = ...): ...
    def _thaw(self, *args, **kwargs): ...
    def addCallback(self, *args, **kwargs): ...
    def addWeakCallback(self, *args, **kwargs): ...
    def bakeCurve(self, *args, **kwargs): ...
    def canHaveCurve(self, *args, **kwargs): ...
    def canHaveExpression(self, *args, **kwargs): ...
    def checkMimeData(self, *args, **kwargs): ...
    def delCallback(self, *args, **kwargs): ...
    def delWeakCallback(self, *args, **kwargs): ...
    def findRelativePolicy(self, *args, **kwargs): ...
    def getArrayChild(self, *args, **kwargs): ...
    def getArrayChildren(self, *args, **kwargs): ...
    def getArraySize(self, *args, **kwargs): ...
    def getAvailableStates(self, *args, **kwargs): ...
    def getChildByName(self, *args, **kwargs): ...
    def getChildren(self, *args, **kwargs): ...
    def getCurve(self, *args, **kwargs): ...
    def getCurveAutoKey(self, *args, **kwargs): ...
    def getCurveKey(self, *args, **kwargs): ...
    def getCurveXml(self, *args, **kwargs): ...
    def getExpression(self, *args, **kwargs): ...
    def getExpressionError(self, *args, **kwargs): ...
    def getExpressionNamespace(self, *args, **kwargs): ...
    def getExpressionReference(self, *args, **kwargs): ...
    def getFullName(self, *args, **kwargs): ...
    def getMimeData(self, *args, **kwargs): ...
    def getName(self): ...
    def getNumChildren(self, *args, **kwargs): ...
    def getOpenStateKey(self, *args, **kwargs): ...
    def getParent(self): ...
    def getSceneGraphLocationPath(self, *args, **kwargs): ...
    def getStateAppearance(self, *args, **kwargs): ...
    def getTooltip(self, *args, **kwargs): ...
    def getType(self, *args, **kwargs): ...
    def getValue(self, *args, **kwargs): ...
    def getValueAsString(self, *args, **kwargs): ...
    def getValueState(self, *args, **kwargs): ...
    def getWidgetHints(self): ...
    def hasFloatingCurve(self, *args, **kwargs): ...
    def isCloseButtonEnabled(self, *args, **kwargs): ...
    def isCurveEnabled(self, *args, **kwargs): ...
    def isCurveViewed(self, *args, **kwargs): ...
    def isExpressionEnabled(self, *args, **kwargs): ...
    def isFrozen(self, *args, **kwargs): ...
    def isGroupParameterBeingEdited(self, *args, **kwargs): ...
    def isLocked(self, *args, **kwargs): ...
    def isValid(self, *args, **kwargs): ...
    def loadCurveFromFile(self, *args, **kwargs): ...
    def removeArrayChild(self, *args, **kwargs): ...
    def reorderArrayChild(self, *args, **kwargs): ...
    def setArraySize(self, *args, **kwargs): ...
    def setCurve(self, *args, **kwargs): ...
    def setCurveAutoKey(self, *args, **kwargs): ...
    def setCurveEnabled(self, *args, **kwargs): ...
    def setCurveKey(self, *args, **kwargs): ...
    def setCurveViewed(self, *args, **kwargs): ...
    def setCurveXml(self, *args, **kwargs): ...
    def setExpression(self, *args, **kwargs): ...
    def setExpressionEnabled(self, *args, **kwargs): ...
    def setMimeData(self, *args, **kwargs): ...
    def setParent(self, *args, **kwargs): ...
    def setValue(self, *args, **kwargs): ...
    def setValueFromString(self, *args, **kwargs): ...
    def setValueState(self, *args, **kwargs): ...
    def setWidgetHints(self, hints): ...
    def shouldDisplayClose(self, *args, **kwargs): ...
    def shouldDisplayState(self, *args, **kwargs): ...
    def shouldDisplayWrench(self, *args, **kwargs): ...
    def toggleValueState(self, *args, **kwargs): ...
    def valueChanged(self, *args, **kwargs): ...
    def waitForReady(self, *args, **kwargs): ...
    def writeCurveToFile(self, *args, **kwargs): ...
    def __getattr__(self, name): ...

def CreateValuePolicyAdapter(sourcePolicy, mapping, alias: str = ..., parent: Incomplete | None = ...): ...
def CreateValuePolicyAdapterMap(sourcePolicy, mapping): ...
def FlattenValuePolicyAdapterMap(mapping, visited: set = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import ExampleTimeTerminalOpDelegate as ExampleTimeTerminalOpDelegate, TerminalOpDelegate as TerminalOpDelegate, WorkingSetTerminalOpDelegate as WorkingSetTerminalOpDelegate
from Nodes3DAPI.Node3D import RegisterTerminalOpDelegate as RegisterTerminalOpDelegate
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from _typeshed import Incomplete
from typing import Any, ClassVar, Set, Tuple

class BaseLookFileBakeOutputFormat:
    DisplayName: ClassVar[None] = ...
    FileExtension: ClassVar[None] = ...
    Hidden: ClassVar[bool] = ...
    PassFileExtension: ClassVar[None] = ...
    def __init__(self, settings: LookFileBakeSettings) -> None: ...
    def postProcess(self, filePaths: list[str]) -> list[str]: ...
    def writeSinglePass(self, passData: LookFilePassData) -> list[str]: ...

class LookFileBakeSettings(_BaseSettings):
    def __init__(self, settings: Incomplete | None = ...) -> None: ...

class LookFilePassData(_BaseSettings):
    def __init__(self, settings: Incomplete | None = ...) -> None: ...

class _BaseSettings:
    def __getitem__(self, key: str) -> Any: ...
    def __setitem__(self, key: str, value: object) -> None: ...

def GetDefaultOutputFormat() -> BaseLookFileBakeOutputFormat | None: ...
def GetOutputFormatByName(outputFormatName: str) -> BaseLookFileBakeOutputFormat: ...
def GetOutputFormatFileExtensions(includeHidden: bool = ...) -> list[str]: ...
def GetOutputFormatNames(includeHidden: bool = ...) -> list[str]: ...
def GetOutputFormats(includeHidden: bool = ...) -> list[BaseLookFileBakeOutputFormat]: ...
def RegisterOutputFormat(outputFormat: BaseLookFileBakeOutputFormat): ...
def SetDefaultOutputFormat(outputFormat: BaseLookFileBakeOutputFormat): ...
def UnregisterOutputFormat(outputFormat: BaseLookFileBakeOutputFormat | str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnGeolib
import RenderManager.RenderSettings
import Utils as Utils
from Callbacks.Callbacks import Callbacks as Callbacks
from typing import ClassVar, Set, Tuple

class NukeSessionMonitor:
    _kCatalogBufferChanged: ClassVar[str] = ...
    _kIdleEvent: ClassVar[str] = ...
    _kRenderCancelledEvent: ClassVar[str] = ...
    _kRenderFinalizedEvent: ClassVar[str] = ...
    _kRenderStoppedEvent: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def _NukeSessionMonitor__buildMappings(self, mapping): ...
    def _NukeSessionMonitor__cleanup(self): ...
    def _NukeSessionMonitor__onCatalogBufferChanged(self, eventType, eventID, **kwargs): ...
    def _NukeSessionMonitor__onIdle(self, eventType, eventId, **kwargs): ...
    def _NukeSessionMonitor__onRenderCancelled(self, eventType: str, mainSequenceIDs: tuple[int, ...]): ...
    def _NukeSessionMonitor__onRenderFinalized(self, eventType: str, eventID: int, renderMethod: str, runtime: PyFnGeolib.GeolibRuntime, node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState, renderUUID: str, renderer: str, renderingSettings: RenderManager.RenderSettings.RenderingSettings, projectSnapshot: ProjectSnapshot | None): ...
    def _NukeSessionMonitor__onRenderStopped(self, eventType: str, completedFrameBuffers): ...
    def _NukeSessionMonitor__onSceneAboutToLoad(self, **kwargs): ...
    @staticmethod
    def _NukeSessionMonitor__tryRegisterEventHandler(eventType, fn): ...
    @staticmethod
    def _NukeSessionMonitor__tryUnregisterEventHandler(eventType, fn): ...
    def _NukeSessionMonitor__unregisterNukeSessions(self, mainSequenceIDs: list[int]): ...
    def registerEvents(self): ...
    def setMappings(self, catalogItem: CatalogAPI.CatalogItem, mapping: dict[str, str]): ...
    def setOutputNodeName(self, catalogItem: CatalogAPI.CatalogItem, outputNodeName: str): ...

def GetNukeSessionMonitor() -> NukeSessionMonitor: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.MessageBox as MessageBox
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel
import Utils as Utils
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from typing import Set, Tuple

class InputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, name, policy, factory) -> None: ...

class LODInputEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def addInput(self): ...
    def buildAddMenu(self, menu): ...
    def deleteInput(self, index): ...
    def deletePanel(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodeGraphView as NodeGraphView
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from typing import Set, Tuple

class NodeGraphViewDrawingLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def idleUpdate(self): ...
    def paintGL(self): ...
    def setLayerStack(self, v): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
from ResourceFiles.ResourceManager import ResourceManager as ResourceManager
from typing import Set, Tuple

class QT4IconManager(ResourceManager):
    def __init__(self, paths, iconDir: str = ..., **kwargs) -> None: ...
    def _QT4IconManager__getData(self, rawPath): ...
    def clearCache(self): ...
    def getIcon(self, fileName): ...
    def getPixmap(self, fileName): ...
    def getSize(self, fileName): ...
    def getSvgRenderer(self, fileName): ...

class _IconData:
    def __init__(self, path) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def IncludeProxyChildrenInWorkingSet(locationPaths: list[str], workingSetName: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import BaseNode as BaseNode, NodeUtils as NodeUtils, Packages as Packages
from typing import Set, Tuple

def IsUIMode() -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from Utils.Exceptions import GetExceptionMessage as GetExceptionMessage
from _typeshed import Incomplete
from types import ModuleType
from typing import ClassVar, Set, Tuple

class NoExceptionProxy:
    def __init__(self, data) -> None: ...
    def __call__(self, *args, **kwargs): ...
    def __getattr__(self, name): ...
    def __getitem__(self, value): ...

class Plugin:
    apinum: ClassVar[int] = ...
    data: ClassVar[object] = ...
    loadTime: ClassVar[float] = ...
    module: ClassVar[ModuleType] = ...
    name: ClassVar[str] = ...
    path: ClassVar[str] = ...
    plugtype: ClassVar[str] = ...
    safe: ClassVar[NoExceptionProxy] = ...
    def __init__(self, path, module, plugtype, apinum, name, data) -> None: ...

def DefaultPaths(subdir: str = ...) -> list[str]: ...
def ExpandPaths(path: str) -> list[str]: ...
def Load(plugtype: str, apinum: str | None, paths: list[str], reloadCached: bool = ..., blacklist: Incomplete | None = ...) -> list[Plugin]: ...
def LoadModule(path: str, reloadCached: bool = ...) -> list[Plugin]: ...
def Search(plugins: list[Plugin], name: str) -> Plugin | None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import GeoAPI as GeoAPI
import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4.FormMaster.Editors.NodeGroup
import Utils as Utils
from typing import Set, Tuple

class Transform3DNodeEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _Transform3DNodeEditor__copyTransform(self, *args): ...
    def _Transform3DNodeEditor__doIdle(self, *args, **kwargs): ...
    def _Transform3DNodeEditor__fitBounds(self, *args): ...
    def _Transform3DNodeEditor__getExistingTransform(self): ...
    def _Transform3DNodeEditor__getInputTransform(self): ...
    def _Transform3DNodeEditor__paneButtonAboutToShow(self, menu): ...
    def _Transform3DNodeEditor__resetTransform(self, *args): ...
    def _Transform3DNodeEditor__setTransformFromMatrix(self, matrix): ...
    def _Transform3DNodeEditor__snapToWorldPos(self, *args): ...
    def _lockChanged(self, state): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import typing
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class IconLabelFrame(PyQt5.QtWidgets.QFrame):
    class NestedIconLabelFrame(PyQt5.QtWidgets.QFrame):
        def __init__(self, iconPixmap: PyQt5.QtGui.QPixmap, text: str, parent: Incomplete | None = ...) -> None: ...
        def getText(self) -> str: ...
        def on_textLabel_linkActivated(self, link: str): ...
        def setForegroundRole(self, foregroundRole: PyQt5.QtGui.QPalette.ColorRole): ...
        def setIconPixmap(self, iconPixmap: PyQt5.QtGui.QPixmap): ...
        def setLinkClickCallback(self, linkClickCallback: typing.Callable | None): ...
        def setText(self, text: str): ...
        def setWordWrap(self, wordWrap: bool): ...
    tabPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, iconPixmap: PyQt5.QtGui.QPixmap, text: str, margin: int = ..., parent: Incomplete | None = ..., flags: PyQt5.QtCore.Qt.WindowType = ...) -> None: ...
    def getText(self) -> str: ...
    def setContentsMargins(self, left: int, top: int, right: int, bottom: int): ...
    def setForegroundRole(self, foregroundRole: PyQt5.QtGui.QPalette.ColorRole): ...
    def setIconPixmap(self, iconPixmap: PyQt5.QtGui.QPixmap): ...
    def setLinkClickCallback(self, linkClickCallback: typing.Callable | None): ...
    def setMargin(self, margin): ...
    def setText(self, text: str): ...
    def setWordWrap(self, wordWrap: bool): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CacheManager as CacheManager
import ConditionalStateGrammar as ConditionalStateGrammar
import ConfigurationAPI_cmodule as Configuration
import PyFnGeolibServices.ExpressionMath as ExpressionMath
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import PluginSystemAPI as PluginSystemAPI
import Utils as Utils
import PyXmlIO as XmlIO
from PyFnGeolibServices.LookFile import LookFile as LookFile
from typing import Set, Tuple

Geolib3BaseDir: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.NodeGroup
import Utils as Utils
from typing import Set, Tuple

class IsolateNodeEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _IsolateNodeEditor__checkBox_CB(self): ...
    def _IsolateNodeEditor__portChangedCB(self, eventType, eventID, **kwargs): ...
    def _IsolateNodeEditor__setupEvents(self, flag): ...
    def _IsolateNodeEditor__update(self): ...
    def _freeze(self): ...
    def _thaw(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import Utils as Utils
from UI4.Util.Events import _UpdateNodegraph as _UpdateNodegraph, debounce as debounce
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

CATEGORY_FILEIN: int
CATEGORY_NODE_CONNECTION: int
CATEGORY_RENDER: int
CATEGORY_SCENEGRAPH: int
CATEGORY_USER: int

class FileInChecker(PyQt5.QtCore.QThread):
    fileInErrors: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, fileIns, t) -> None: ...
    def run(self): ...

class _FileInUpdaterClass:
    def __init__(self) -> None: ...
    def _FileInUpdaterClass__check(self): ...
    def _FileInUpdaterClass__errorsCB(self, errorList, time): ...
    def _FileInUpdaterClass__shouldCheckFileIn(self, node: NodegraphAPI.Node, t: Incomplete | None = ...): ...
    def checkWithDelay(self, nodes: Incomplete | None = ...): ...
    def flushCache(self, args: Incomplete | None = ...): ...
    def loadBegin(self, eventType, eventID, **kwargs): ...
    def loadEnd(self, eventType, eventID, **kwargs): ...
    def nodeCreate(self, eventType, eventID, **kwargs): ...
    def nodeRenamed(self, args): ...
    def parameterFinalizeValue(self, eventType, eventID, **kwargs): ...
    def reset(self): ...
    def timeChange(self, args): ...

def ClearNodeError(node: NodegraphAPI.Node, redraw: bool = ...): ...
def ClearNodeErrors(category: int = ..., redraw: bool = ...): ...
def GetNodeError(node: NodegraphAPI.Node): ...
def IterAllErrorNodes(): ...
def SetCheckingEnabled(enabled, category: Incomplete | None = ...): ...
def SetNodeError(node: NodegraphAPI.Node, error, category: int = ..., redraw: bool = ..., setParentError: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def BuildLogMesasgeWithCaller(message): ...
def BuildLogMessageWithCaller(message, frameIndex: int = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyXmlIO as PyXmlIO
import PyQt5.QtCore as QtCore
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def CheckKeyMimeData(parameters, mimeData, strictTypeCB: Incomplete | None = ...): ...
def CheckKeyMimeDataGeneric(mimeData): ...
def GetKeyMimeData(parameters, strictTypeCB: Incomplete | None = ...): ...
def GetKeyMimeDataPotentials(parameters, mimeData, timeOffset: Incomplete | None = ..., targetTime: Incomplete | None = ...): ...
def GetKeyMimeDataSources(mimeData): ...
def SetKeyMimeData(parameters, mimeData, timeOffset: Incomplete | None = ..., targetTime: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import UI4.Util.IconManager as IconManager
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnGeolibProducers
import PyQt5.QtCore
import PyQt5.QtGui
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import PyUtilModule.ScenegraphUtils as ScenegraphUtils
import Utils as Utils
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CameraPickerButton(FilterablePopupButton):
    DISPLAY_CAMERAS: ClassVar[int] = ...
    DISPLAY_LIGHTS: ClassVar[int] = ...
    lookThrough: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ..., flat: bool = ..., showIcon: bool = ..., specialItems: Incomplete | None = ..., showBuiltIns: bool = ..., abbreviateNames: bool = ...) -> None: ...
    def _CameraPickerButton__asyncGetProducerAtLocation(self, location: str): ...
    def _CameraPickerButton__getCameraLocations(self): ...
    def _CameraPickerButton__getLightLocations(self): ...
    def _CameraPickerButton__getLocationType(self, locationPath): ...
    def _CameraPickerButton__getProducerAtLocation(self, location: str) -> PyFnGeolibProducers.GeometryProducer | None: ...
    def _CameraPickerButton__getRenderCameraPath(self): ...
    def _CameraPickerButton__on_event_idle(self, *args, **kwargs): ...
    def _CameraPickerButton__setupClient(self): ...
    def _CameraPickerButton__validateLocation(self, locationPath): ...
    def _CameraPickerButton__validateLocationExists(self, locationPath): ...
    def _shouldValidateLocation(self) -> bool: ...
    def addBuiltin(self, name: str): ...
    def clearBuiltins(self): ...
    def dragEnterEvent(self, event: PyQt5.QtGui.QDragEnterEvent): ...
    def dropEvent(self, event: PyQt5.QtGui.QDropEvent): ...
    def getBuiltInCameraPath(self, cameraName): ...
    def getBuiltInNameFromPath(self, cameraPath): ...
    def getBuiltIns(self): ...
    def on_aboutToShow(self): ...
    def on_checkbox_stateChanged(self, state: PyQt5.QtCore.Qt.CheckState): ...
    def on_itemChosen(self, value: str, meta: tuple): ...
    def on_validateLocationsCheckbox_stateChanged(self, state: PyQt5.QtCore.Qt.CheckState): ...
    def populate(self): ...
    def setCameraPath(self, path: str): ...
    def setDisplayMode(self, displayMode: int): ...
    def setScenegraphPixmap(self, pixmap: PyQt5.QtGui.QPixmap | None): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import UI4.Util.Caches as Caches
import PyFnAttribute as FnAttribute
import PyFnGeolibProducers as FnGeolibProducers
import QT4FormWidgets.InputWidgets as InputWidgets
import LookFileBakeAPI as LookFileBakeAPI
import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyFnGeolibProducers
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.FormMaster.Editors.NodeGroup
import UI4.Util.AssetId
import UI4.Widgets.SortablePanel
import Utils as Utils
from LookFileBakeAPI.Exceptions import LookFileBakeException as LookFileBakeException
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class InputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, name) -> None: ...
    def _InputPanel__valueChangedCallback(self): ...
    def getPassName(self): ...
    def setPassName(self, name): ...

class LookFileAssetSaveDialog(UI4.Util.AssetId.BrowseForAssetDialog):
    def __init__(self, parent, hints, node: NodegraphAPI.Node) -> None: ...

class LookFileBakeEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    class InterruptionException(Exception): ...
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _LookFileBakeEditor__findInstancesBeneathSelection(self): ...
    def _LookFileBakeEditor__interruptCallback(self): ...
    def _LookFileBakeEditor__locationsMenuAboutToShow(self, menu): ...
    def _LookFileBakeEditor__productChanged(self, event): ...
    def _LookFileBakeEditor__progressCallback(self, message: Incomplete | None = ...): ...
    def _LookFileBakeEditor__validityChanged(self, valid): ...
    def _LookFileBakeEditor__writeCallback(self): ...
    def _freeze(self): ...
    def _thaw(self): ...

class LookFileBakeMultipassInputEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _LookFileBakeMultipassInputEditor__getEventTarget(self): ...
    def _LookFileBakeMultipassInputEditor__getNode(self): ...
    def _LookFileBakeMultipassInputEditor__idle_callback(self, *args, **kwargs): ...
    def _LookFileBakeMultipassInputEditor__node_addOrRemoveInputPort_cb(self, eventType, eventID, nodeName, portName, port: NodegraphAPI.Port, **kwargs): ...
    def addInput(self): ...
    def buildAddMenu(self, menu): ...
    def deleteInput(self, index): ...
    def deletePanel(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def panelValueChanged(self, index): ...
    def renameInput(self, index, newName): ...
    def valueChanged(self, valuePolicy, index, final): ...

class LookFileMaterialsOutEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    class InterruptionException(Exception): ...
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _LookFileMaterialsOutEditor__interruptCallback(self): ...
    def _LookFileMaterialsOutEditor__progressCallback(self, message: Incomplete | None = ...): ...
    def _LookFileMaterialsOutEditor__writeCallback(self): ...

class LookFileResolveEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _LookFileResolveEditor__flushCallback(self): ...

class LookFileRootResolveEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _LookFileRootResolveEditor__flushCallback(self): ...

class SceneSearchDialog(PyQt5.QtWidgets.QDialog):
    COUNT_COLUMN: ClassVar[int] = ...
    DERIVED_COLUMN: ClassVar[int] = ...
    KSTD_COLUMN: ClassVar[int] = ...
    SOURCE_COLUMN: ClassVar[int] = ...
    def __init__(self, node: NodegraphAPI.Node, mode) -> None: ...
    def _SceneSearchDialog__appendButtonCB(self): ...
    def _SceneSearchDialog__checkInterrupt(self, path: str = ...): ...
    def _SceneSearchDialog__filterFieldUpdate(self, filterText, filterType): ...
    def _SceneSearchDialog__findDerivedComponentSource(self, spref): ...
    def _SceneSearchDialog__findScenegraphSelectionRoots(self): ...
    def _SceneSearchDialog__getExistingPaths(self): ...
    def _SceneSearchDialog__getUniqueVisibleLocations(self): ...
    def _SceneSearchDialog__getUniqueVisibleLocationsNotInExistingPaths(self): ...
    def _SceneSearchDialog__interrupt(self): ...
    def _SceneSearchDialog__replaceButtonCB(self): ...
    def _SceneSearchDialog__startFind(self): ...
    def _SceneSearchDialog__walkLocation(self, producer: PyFnGeolibProducers.GeometryProducer, productItems): ...
    def showEvent(self, ev): ...

class _InterruptException(RuntimeError): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import AssetBrowser as AssetBrowser
import AssetBrowser.Browser
import UI4.Util.AssetWidgetDelegatePlugins as AssetWidgetDelegatePlugins
import CatalogAPI as CatalogAPI
import UI4.Util.ExternalTools as ExternalTools
import UI4.Util.KatanaMediaCache as KatanaMediaCache
import MediaCacheHandler as MediaCacheHandler
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class AssetIdHelper(PyQt5.QtCore.QObject):
    extraImageInfo: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    showExtendedInfo: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, policy) -> None: ...
    def _AssetIdHelper__chooseAsset(self): ...
    def _AssetIdHelper__extraMenuHookAction(self, action): ...
    def _AssetIdHelper__imageInfoThreadResult(self, filename: str, info: dict): ...
    def _AssetIdHelper__launchImageViewer(self): ...
    def _AssetIdHelper__mediaCacheCallback(self): ...
    def _AssetIdHelper__presetActionTriggered(self, action): ...
    def _AssetIdHelper__setNodeNameFromPath(self): ...
    def fillMenu(self, menu, locked): ...
    def getValuePolicy(self): ...
    def requestExtraImageInfo(self): ...
    def setAssetWidgetDelegate(self, assetWidgetDelegate): ...
    def setSaveMode(self, saveMode): ...

class BrowseForAssetDialog(AssetBrowser.Browser.BrowserDialog):
    def __init__(self, assetOrFile, label: Incomplete | None = ..., saveMode: bool = ..., hints: Incomplete | None = ...) -> None: ...

class ImageInfoThread(PyQt5.QtCore.QThread):
    imageInfo: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, filename) -> None: ...
    def run(self): ...

class _SelfTriggerAction(PyQt5.QtWidgets.QAction):
    trigger: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, message, parent) -> None: ...
    def _SelfTriggerAction__go(self): ...

def BrowseForAsset(assetOrFile, label, saveMode, hints, extraOptions: Incomplete | None = ...): ...
def GetExtraImageInfo(fileName): ...
def LaunchImageViewer(filename, processName: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from QT4FormWidgets.WidgetFactory import WidgetFactory
from typing import Set, Tuple

class AssetPluginPopupFormWidget(BaseAssetApiPluginPopupFormWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...

class BaseAssetApiPluginPopupFormWidget(PopupFormWidget):
    def __init__(self, pluginNames: list[str], parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...

class FileSequencePluginPopupFormWidget(BaseAssetApiPluginPopupFormWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4 as UI4
import UI4.Widgets.SortableParams
from typing import Set, Tuple

class SortableParamsForm(UI4.Widgets.SortableParams.SortableParamsFormWidget): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

class _HotrenderInterrupt:
    def __init__(self) -> None: ...
    def _HotrenderInterrupt__interrupt(self): ...
    def close(self): ...
    def serialHotrenderCB(self, message: Incomplete | None = ...): ...

def SerialHotRender(nodeList, node: typing.Optional[NodegraphAPI.Node] = ..., renderMethodName: Incomplete | None = ..., remoteRender: bool = ..., renderFarm: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors as Editors
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import typing
from QT4FormWidgets.WidgetFactory import WidgetFactory
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

AttributeWidgetFactory: AttributeWidgetFactoryClass
KatanaWidgetFactory: KatanaWidgetFactoryClass
ParameterWidgetFactory: ParameterWidgetFactoryClass

class AttributeWidgetFactoryClass(KatanaWidgetFactoryClass):
    REMAPS: ClassVar[set] = ...
    def _getWidgetClass(self, policy, hints): ...

class KatanaWidgetFactoryClass(WidgetFactory):
    _KatanaWidgetFactoryClass__defaultWidgetTypes: ClassVar[dict] = ...
    def _getWidgetClass(self, policy: QT4FormWidgets.AbstractValuePolicy, hints: dict, widgetType: Incomplete | None = ...) -> type | None: ...
    def buildWidget(self, parent: PyQt5.QtWidgets.QWidget, policy: typing.Union[QT4FormWidgets.AbstractValuePolicy, None]) -> QT4FormWidgets.FormWidget: ...

class ParameterWidgetFactoryClass(KatanaWidgetFactoryClass):
    def _getWidgetClass(self, policy, hints): ...

def LoadAllEditors(): ...
def LookupWidgetType(name): ...
def RegisterPluginWidget(widgetType, widgetClass): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyUtilModule.Documentation as Documentation
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.FormMaster.NodeActionDelegate as NodeActionDelegate
import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyFCurve as PyFCurve
import PyQt5.QtCore
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import UI4.FormMaster.States as States
import PyUtilModule.UserNodes as UserNodes
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import Set, Tuple

class BaseParameterPolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, param, parent) -> None: ...
    def _BaseParameterPolicy__applyToGroups(self, param, action): ...
    def _BaseParameterPolicy__getExtensionForNode(self, node: NodegraphAPI.Node): ...
    def _BaseParameterPolicy__getUserParametersEditState(self): ...
    def _BaseParameterPolicy__parameter_showKeys_callback(self, args): ...
    def _BaseParameterPolicy__removeHint(self, param): ...
    def _BaseParameterPolicy__resetParameters(self): ...
    def _BaseParameterPolicy__saveAndPublishMacro(self, node: NodegraphAPI.Node, filePathOrAssetId, extraOptions: dict = ...): ...
    def _BaseParameterPolicy__saveAsMacro(self): ...
    def _BaseParameterPolicy__setHint(self, param): ...
    def _BaseParameterPolicy__setUpEventHandlers(self, enable): ...
    def _BaseParameterPolicy__toggleNodeInputConnectionVisibility(self): ...
    def _BaseParameterPolicy__toggleShowHiddenParams(self): ...
    def _BaseParameterPolicy__toggleUserParameterState(self): ...
    def _BaseParameterPolicy__writeMacroFile(self, node: NodegraphAPI.Node, filename, createFoldersRecursively: bool = ...): ...
    def _appendToWrenchMenu(self, menu): ...
    def _cleanUpExpression(self, rawExpr): ...
    def _freeze(self): ...
    def _hintsChanged(self): ...
    def _thaw(self): ...
    def canHaveExpression(self): ...
    def getCurveXml(self): ...
    def getExpression(self): ...
    def getExpressionError(self): ...
    def getExpressionNamespace(self): ...
    def getExpressionReference(self): ...
    def getMimeData(self) -> PyQt5.QtCore.QMimeData: ...
    def getName(self): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getNumChildren(self): ...
    def getParameter(self): ...
    def getSceneGraphLocationPath(self) -> str | None: ...
    def getStateAppearance(self, state): ...
    def getTooltip(self): ...
    def getType(self): ...
    def getWidgetHints(self): ...
    def isExpressionEnabled(self): ...
    def isGroupParameterBeingEdited(self): ...
    def isLocked(self): ...
    def isValid(self) -> bool: ...
    def setCurveXml(self, xml): ...
    def setExpression(self, expr): ...
    def setExpressionEnabled(self, flag): ...
    def setMimeData(self, mimeData, dropAction): ...
    def shouldDisplayWrench(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
import typing
from NodeGraphTab.NodegraphPanel import NodegraphPanel
from _typeshed import Incomplete
from typing import Any, Set, Tuple

class LayeredMenu:
    def __init__(self, populateCallback: typing.Callable, actionCallback: typing.Callable, keyboardShortcut: str, alwaysPopulate: bool = ..., onlyMatchWordStart: bool = ..., sortAlphabetically: bool = ..., checkAvailabilityCallback: typing.Optional[typing.Callable] = ...) -> None: ...
    def addEntry(self, value: object, text: Incomplete | None = ..., color: Incomplete | None = ..., size: Incomplete | None = ..., textColor: Incomplete | None = ...): ...
    def alwaysPopulate(self) -> bool: ...
    def checkAvailability(self, tab: NodegraphPanel) -> bool: ...
    def clear(self): ...
    def getAssociatedRenderer(self) -> str: ...
    def getChosenValue(self) -> Any | None: ...
    def getEntries(self) -> list[LayeredMenuEntry]: ...
    def getKeyboardShortcut(self) -> str: ...
    def isPopulated(self) -> bool: ...
    def onEntryChosen(self, value: object, tab: NodegraphPanel) -> Any | None: ...
    def onlyMatchWordStart(self) -> bool: ...
    def populate(self, tab: NodegraphPanel) -> bool: ...
    def setAssociatedRenderer(self, associatedRenderer: str): ...
    def setChosenValue(self, value: object | None): ...
    def shouldSortAlphabetically(self) -> bool: ...

class LayeredMenuEntry:
    def __init__(self, value: object, text: Incomplete | None = ..., color: Incomplete | None = ..., size: Incomplete | None = ..., textColor: Incomplete | None = ...) -> None: ...
    def getColor(self) -> None | None: ...
    def getSize(self) -> None | None: ...
    def getText(self) -> str: ...
    def getTextColor(self) -> None | None: ...
    def getValue(self) -> Any: ...

def GetLayeredMenu(layeredMenuID: str) -> LayeredMenu | None: ...
def GetLayeredMenuIDByAssociatedRenderer(associatedRenderer: str) -> str | None: ...
def GetLayeredMenuIDs() -> list[str]: ...
def RegisterLayeredMenu(layeredMenu: LayeredMenu, layeredMenuID: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class StatefulAction(PyQt5.QtWidgets.QAction):
    def __init__(self, name, parent, data, extraSettings: dict = ...) -> None: ...
    def _StatefulAction__triggered(self, checked): ...
    def getData(self): ...
    def updateState(self): ...

class StatefulMenu(PyQt5.QtWidgets.QMenu):
    def __init__(self, title, parent: Incomplete | None = ...) -> None: ...
    def _StatefulMenu__update(self): ...
    def build(self, data, extraSettings: dict = ...): ...
    def setUpdateOnShow(self, updateOnShow): ...

def MergeStatefulMenuData(original, update): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LogView(PyQt5.QtWidgets.QAbstractScrollArea):
    _ScrollbarPositionsCache: ClassVar[dict] = ...
    autoScrollingChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    numLinesChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None) -> None: ...
    def _LogView__immediateAppend(self, text): ...
    def _LogView__on_scrollBar_actionTriggered(self, _action: int): ...
    def _LogView__on_verticalScrollBar_valueChanged(self, value: int): ...
    def _LogView__scrollTimer_CB(self): ...
    def _LogView__scrollToEndOfLog(self, temporarilyBlockSignals: bool = ...): ...
    def _LogView__updateCachedFontProperties(self): ...
    def _LogView__updateTimer_CB(self): ...
    def _clearCachedScrollbarPositions(self, scrollbarPositionsCacheKey: str): ...
    def _isAutoScrolling(self) -> bool: ...
    def _restoreScrollbarPositionsFromCache(self, scrollbarPositionsCacheKey: str): ...
    def _setAutoScrolling(self, autoScrolling: bool): ...
    def _storeScrollbarPositionsInCache(self, scrollbarPositionsCacheKey: str): ...
    def append(self, text): ...
    def changeEvent(self, event: PyQt5.QtCore.QEvent): ...
    def clear(self): ...
    def drawInsertionLine(self, p, textIndex): ...
    def getCharacterMap(self, bold: Incomplete | None = ..., color: Incomplete | None = ..., selected: Incomplete | None = ..., backgroundColor: Incomplete | None = ...): ...
    def getLogText(self, startIndex: Incomplete | None = ..., endIndex: Incomplete | None = ...): ...
    def getNumLines(self): ...
    def getSelectedText(self) -> str: ...
    def mouseMoveEvent(self, e): ...
    def mousePressEvent(self, e): ...
    def mouseReleaseEvent(self, e): ...
    def paintEvent(self, event): ...
    def resizeEvent(self, event): ...
    def setUpdateThrottle(self, timeMS): ...
    def textIndexAtPosition(self, pos): ...
    def updateScrollbars(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.App.Tabs
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class TabDockWidget(PyQt5.QtWidgets.QDockWidget):
    _TabDockWidget__closeDockedTabIcon: ClassVar[None] = ...
    _TabDockWidget__detachTabIcon: ClassVar[None] = ...
    def __init__(self, tabWithTimeline: UI4.App.Tabs.TabWithTimeline, parent: Incomplete | None = ...) -> None: ...
    def _TabDockWidget__on_detachTabButton_clicked(self): ...
    def _TabDockWidget__on_dockLocationChanged(self, area: PyQt5.QtCore.Qt.DockWidgetArea): ...
    def _TabDockWidget__updateTitleBarButtons(self): ...
    def closeEvent(self, event: PyQt5.QtGui.QCloseEvent): ...
    def event(self, event: PyQt5.QtCore.QEvent) -> bool: ...
    def setWindowTitle(self, windowTitle: str): ...
    def windowTitle(self) -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import drawing_cmodule as DrawingModule
import NodegraphAPI as NodegraphAPI
import Utils as Utils
from typing import Set, Tuple

def GetDrawOutputsAttr(node: NodegraphAPI.Node): ...
def SetDrawOutputsAttr(node: NodegraphAPI.Node, value): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Color.ColorPolicy as ColorPolicy
import QT4Color.Globals as Globals
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import ClassVar, Set, Tuple

class CursorWidget(PyQt5.QtWidgets.QFrame):
    def __init__(self, *args) -> None: ...
    def paintEvent(self, ev): ...
    def setPixmap(self, pm): ...

class ScreenScraperPushButton(PyQt5.QtWidgets.QPushButton, ScreenScraperQButtonMixin):
    def __init__(self, *args) -> None: ...
    def closeEvent(self, ev): ...
    def hideEvent(self, ev): ...

class ScreenScraperQButtonMixin:
    _ScreenScraperQButtonMixin__DROPPER_ICON: ClassVar[str] = ...
    color: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def _ScreenScraperQButtonMixin__dispatchEvent(self): ...
    def _ScreenScraperQButtonMixin__setColor(self, color, final: bool = ...): ...
    def _ScreenScraperQButtonMixin__startSampling(self): ...
    def _ScreenScraperQButtonMixin__stopSampling(self): ...
    def _ScreenScraperQButtonMixin__updateCursor(self): ...
    def doCloseEvent(self, ev): ...
    def doHideEvent(self, ev): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def mouseReleaseEvent(self, ev): ...
    def setReadOnly(self, value): ...

class ScreenScraperToolButton(PyQt5.QtWidgets.QToolButton, ScreenScraperQButtonMixin):
    def __init__(self, *args) -> None: ...
    def closeEvent(self, ev): ...
    def hideEvent(self, ev): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.Xio as Xio
from NodegraphAPI.Version.Registry import GetNodeTypeVersionUpdateFunctions as GetNodeTypeVersionUpdateFunctions
from typing import Set, Tuple

def UpdateNodeTypeVersions(document): ...
def WillUpdateNodeTypeVersions(document): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import ASCColorCorrector as ASCColorCorrector, ColorPolicy as ColorPolicy, ColorTransforms as ColorTransforms, Degenerate as Degenerate, DropType as DropType, Globals as Globals, Gradient1D as Gradient1D, Gradient2D as Gradient2D, ScreenScraper as ScreenScraper, Swatches as Swatches, WidgetUtils as WidgetUtils
from QT4Color.ASCColorCorrector import ColorGradeWidget as ColorGradeWidget, MonitorGammaWidget as MonitorGammaWidget
from QT4Color.ColorDropWidget import ColorDropWidget as ColorDropWidget
from QT4Color.ColorFormWidget import ColorComponentTabGroup as ColorComponentTabGroup, ColorFormWidget as ColorFormWidget, UpdateThrottler as UpdateThrottler
from QT4Color.ColorPicker import ColorPicker as ColorPicker, ModalColorPicker as ModalColorPicker
from QT4Color.ColorPolicy import CreateColorPolicy as CreateColorPolicy, DoesColorPolicyEnableFilmlook as DoesColorPolicyEnableFilmlook, DoesColorPolicyEnableNoFilmlookColorSpace as DoesColorPolicyEnableNoFilmlookColorSpace, DoesColorPolicyHaveAlpha as DoesColorPolicyHaveAlpha, DoesColorPolicyRestrictComponents as DoesColorPolicyRestrictComponents, GetColorPolicyChildren as GetColorPolicyChildren, GetColorPolicyRGBA as GetColorPolicyRGBA, GetDefaultColorComponentTab as GetDefaultColorComponentTab, SetColorPolicyEnableFilmlook as SetColorPolicyEnableFilmlook, SetColorPolicyEnableFilmlookDefault as SetColorPolicyEnableFilmlookDefault, SetColorPolicyEnableNoFilmlookColorSpaceDefault as SetColorPolicyEnableNoFilmlookColorSpaceDefault, SetColorPolicyRGBA as SetColorPolicyRGBA, SetColorPolicyRestrictComponents as SetColorPolicyRestrictComponents, SetColorPolicyRestrictComponentsDefault as SetColorPolicyRestrictComponentsDefault
from QT4Color.ColorTextWidget import ColorFromText as ColorFromText, ColorTextValidator as ColorTextValidator, ColorTextWidget as ColorTextWidget, ColorToText as ColorToText
from QT4Color.ColorTransforms import ClampRGBA as ClampRGBA, ConvertColorToUnits as ConvertColorToUnits, ConvertUnitsToColor as ConvertUnitsToColor
from QT4Color.Degenerate import IsComponentDegenerate as IsComponentDegenerate, UnDegenerator as UnDegenerator
from QT4Color.DropType import BuildDragDataFromInfo as BuildDragDataFromInfo, BuildDragPixmapFromColor as BuildDragPixmapFromColor, GetColorDragType as GetColorDragType, GetColorInfoFromDragObject as GetColorInfoFromDragObject, GetColorPolicyDragDict as GetColorPolicyDragDict
from QT4Color.GammaWidget import GammaWidget as GammaWidget
from QT4Color.Globals import ApplyFilmlook as ApplyFilmlook, GetErrorMessageForColor as GetErrorMessageForColor, GetGlobalColorPolicy as GetGlobalColorPolicy, GetGlobalDisplay as GetGlobalDisplay, Get_UseFixedSatHSV as Get_UseFixedSatHSV, Get_UseSingleComponentRGB as Get_UseSingleComponentRGB, SetGlobalDisplay as SetGlobalDisplay, Set_UseFixedSatHSV as Set_UseFixedSatHSV, Set_UseSingleComponentRGB as Set_UseSingleComponentRGB
from QT4Color.Gradient1D import LinearGradientWidget as LinearGradientWidget
from QT4Color.Gradient2D import Gradient2DWidget as Gradient2DWidget
from QT4Color.Histogram import Histogram as Histogram, HistogramChannel as HistogramChannel, HistogramWidget as HistogramWidget
from QT4Color.HueColorWidget import HueColorWidget as HueColorWidget
from QT4Color.LumaSliderWidget import LumaSliderWidget as LumaSliderWidget
from QT4Color.ScreenScraper import ScreenScraperPushButton as ScreenScraperPushButton, ScreenScraperToolButton as ScreenScraperToolButton
from QT4Color.Swatches import BuildSwatchPixmap as BuildSwatchPixmap, BuildSwatchPixmapForPolicy as BuildSwatchPixmapForPolicy, GetSwatchColors as GetSwatchColors, PaintColorSwatch as PaintColorSwatch
from QT4Color.TempColorWidget import TempColorWidget as TempColorWidget, TempColorWidgetBase as TempColorWidgetBase
from QT4Color.WidgetUtils import MiniLabelButton as MiniLabelButton, SetCompactWidgetWidth as SetCompactWidgetWidth, StripedFrame as StripedFrame
from typing import Set, Tuple

SMALL: float



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConditionalStateGrammar as ConditionalStateGrammar
import Nodes3DAPI.DynamicParameterUtil as DynamicParameterUtil
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI as NodegraphAPI
import PyFnAttribute
import PyXmlIO as PyXmlIO
import Naming as UniqueName
import Utils as Utils
from ConditionalStateGrammar.Parser import ParseCSG as ParseCSG
from Nodes3DAPI.Node3D import Node3D as Node3D
from Nodes3DAPI_cmodule import BuildAttrListFromDynamicParameterGroup as BuildAttrListFromDynamicParameterGroup
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class RendererProceduralArgs(Node3D):
    _RendererProceduralArgs__incomingCookKey: ClassVar[str] = ...
    _RendererProceduralArgs__rootHints: ClassVar[dict] = ...
    def __init__(self) -> None: ...
    def _RendererProceduralArgs__appendTemplateGroupChildrenOp(self, interface, location, locationCEL): ...
    def _RendererProceduralArgs__checkDynamicParametersInternal(self, universalAttr: Incomplete | None = ..., forceUpdate: bool = ...): ...
    def _getIncomingSceneOpAndLocation(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, transaction): ...
    def _getOpChain(self, interface): ...
    def _getStaticAttrHintsForIncomingSceneQuery(self, attrPath): ...
    def _updateParameters(self, groupAttr, force: bool = ..., defaultAttr: Incomplete | None = ...): ...
    def addAttributeEntry(self, attr: PyFnAttribute.Attribute, path: str, hints: dict): ...
    def addParameterHints(self, attrName, inputDict): ...
    def addTemplateGroup(self, param, templateName): ...
    def checkDynamicParameters(self, *args, **kwds): ...
    def clearParamHistory(self): ...
    def deleteAttributeEntry(self, index: int): ...
    def forceRebuildParameters(self): ...
    def getAttributeEntries(self) -> NodegraphAPI.Parameter: ...
    def getFixedCELStatement(self): ...
    def getInfoString(self): ...
    def getProceduralScenegraphLocation(self, sourceTime: int = ...): ...
    def getScenegraphLocation(self): ...
    def initializeFromRendererProceduralAttr(self, attr): ...
    def reorderAttributeEntries(self, oldPos: int, oldPosCount: int, newPos: int, newPosCount: int): ...
    def reorderAttributeEntry(self, oldPos: int, newPos: int): ...
    def setRendererProceduralArgValue(self, paramName, newValue): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import Callbacks as Callbacks
import UI4.FormMaster.NodeActionDelegate.NodeActionDelegate as NodeActionDelegate
import UI4.Util.NodeGraphTab as NodeGraphTab
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from NodegraphAPI.LiveGroup import AssetPublishing as AssetPublishing
from UI4.FormMaster.NodeActionDelegate.BaseNodeActionDelegate import BaseNodeActionDelegate as BaseNodeActionDelegate
from _typeshed import Incomplete
from typing import Set, Tuple

class LiveGroupActionDelegate(BaseNodeActionDelegate):
    class _ConvertToGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
        def _ConvertToGroupAction__triggered(self, checked): ...

    class _EditContentsLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _EditContentsLiveGroupAction__triggered(self, checked): ...

    class _EditParentsAndContentsLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _EditParentsAndContentsLiveGroupAction__hasLiveGroupAncestor(self): ...
        def _EditParentsAndContentsLiveGroupAction__triggered(self, checked): ...

    class _LoadLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _LoadLiveGroupAction__triggered(self, checked): ...

    class _PublishAndFinishEditingContentsLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _PublishAndFinishEditingContentsLiveGroupAction__triggered(self, checked): ...

    class _PublishLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _PublishLiveGroupAction__triggered(self, checked): ...

    class _ReloadLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node, enabled: bool = ...) -> None: ...
        def _ReloadLiveGroupAction__triggered(self, checked): ...

    class _RevertLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
        def _RevertLiveGroupAction__triggered(self, checked): ...
    def _buildMenu(self, menu, node: NodegraphAPI.Node): ...
    def addToContextMenu(self, menu, node: NodegraphAPI.Node): ...
    def addToWrenchMenu(self, menu, node: NodegraphAPI.Node, hints: Incomplete | None = ...): ...

def PublishLiveGroup(liveGroupNode: NodegraphAPI.LiveGroupNode, reloadContent: bool, dialogTitle: str) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Color as QT4Color
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

_ColorLabels: list
_PastelLabels: list

class ColorAction(PyQt5.QtWidgets.QAction):
    def __init__(self, c3f, text, parent, nodes: Incomplete | None = ...) -> None: ...
    def _ColorAction__activatedCB(self): ...
    def _ColorAction__buildIcon(self): ...

class NodeColorsMenu(PyQt5.QtWidgets.QMenu):
    nodeSelected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ..., nodes: Incomplete | None = ...) -> None: ...
    def _NodeColorsMenu__doAboutToShow(self): ...
    def _NodeColorsMenu__doActivated(self, action): ...

def SetNodeColorCustom(nodes: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack.LayerStack as LayerStack
import QT4GLLayerStack.LayerStack
from typing import Set, Tuple

class EventEaterLayer(QT4GLLayerStack.LayerStack.Layer):
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import Set, Tuple

class CatalogResolutionWidget(PyQt5.QtWidgets.QLabel):
    def __init__(self, *args) -> None: ...
    def _CatalogResolutionWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogResolutionWidget__catalog_itemPropertyUpdate_CB(self, eventType, eventID, item, **kwargs): ...
    def mousePressEvent(self, ev): ...
    def setCatalogItem(self, catalogItem): ...
    def updateState(self, *args, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class FastLabel(PyQt5.QtWidgets.QWidget):
    def __init__(self, text, parent) -> None: ...
    def _FastLabel__growWidth(self): ...
    def alignment(self): ...
    def minimumSizeHint(self): ...
    def paintEvent(self, event): ...
    def setAlignment(self, alignment): ...
    def setText(self, text): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CacheManager as CacheManager
import ConfigurationAPI_cmodule as Configuration
import NodegraphAPI.NodeExtensions as NodeExtensions
import NodegraphAPI
import NodegraphAPI_cmodule as NodegraphAPI_cmodule
import NodegraphAPI.NodegraphGlobals as NodegraphGlobals
import PyXmlIO as PyXmlIO
import PyResolutionTableFn as ResolutionTable
import Utils as Utils
import NodegraphAPI.Version as Version
import typing
from NodegraphAPI_cmodule import Context as Context
from _typeshed import Incomplete
from typing import Set, Tuple

def BuildNodegraphXmlIO(forcePersistant: bool = ..., opaqueParams: Incomplete | None = ..., isAutoSave: bool = ...): ...
def BuildNodesXmlIO(nodes: list[NodegraphAPI.Node], forcePersistant: bool = ..., opaqueParams: Incomplete | None = ..., requireSiblings: bool = ..., progressCallback: typing.Optional[typing.Callable] = ..., includeNonPersistentNodes: bool = ...) -> PyXmlIO.Element | None: ...
def GetUserNodesXmlRootAttrs(): ...
def LoadElementsFromFile(fileName, versionUp: bool = ...): ...
def LoadElementsFromString(xmlString, versionUp: bool = ...): ...
def ParseNodegraphXmlIO(element: PyXmlIO.Element, sourcePath: str = ..., isCrashFile: bool = ...): ...
def ParseNodesXmlIO(element: PyXmlIO.Element, emit: bool = ..., floatNodes: bool = ..., sourcePath: str = ..., loadLiveGroups: bool = ..., lockLiveGroups: bool = ..., isParentContextNME: bool = ...) -> list: ...
def SetUserNodesXmlRootAttrs(attrDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Widgets.PopdownLabel import PopdownLabel as PopdownLabel
from _typeshed import Incomplete
from typing import Set, Tuple

class AssetIDLabel(PopdownLabel):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def buildMenu(self, menu: PyQt5.QtWidgets.QMenu): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import QT4Widgets.WidgetUtils as WidgetUtils
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class MenuButton(PyQt5.QtWidgets.QPushButton):
    dragEnterEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dragLeaveEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dropEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    mousePressEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, text: str = ..., alignWidget: Incomplete | None = ...) -> None: ...
    def _MenuButton__aboutToHideMenu(self): ...
    def _MenuButton__positionArrow(self): ...
    def _displayMenu(self): ...
    def contextMenuEvent(self, event): ...
    def dragEnterEvent(self, event): ...
    def dragLeaveEvent(self, event): ...
    def dropEvent(self, event): ...
    def event(self, event: PyQt5.QtCore.QEvent) -> bool: ...
    def menu(self): ...
    def mousePressEvent(self, event): ...
    def resizeEvent(self, event): ...
    def setArrowVisible(self, value): ...
    def setButtonType(self, buttonType): ...
    def setFlat(self, flat): ...
    def setMenu(self, menu): ...
    def setPixmap(self, pixmap): ...
    def sizeHint(self): ...

class PassThroughLabel(PyQt5.QtWidgets.QLabel):
    def mousePressEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyXmlIO as PyXmlIO
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import types
import typing
from PyQt5.QtCore import __lastModifiers as __lastModifiers
from UI4.App.KeyboardShortcutManager.KeyboardShortcutModel import KeyboardShortcutModel as KeyboardShortcutModel
from UI4.App.KeyboardShortcutManager.ManagedAction import ManagedAction as ManagedAction
from _typeshed import Incomplete
from typing import Set, Tuple

def BindActions(contextName: str, widget: PyQt5.QtWidgets.QWidget, callbackInstance: Incomplete | None = ...): ...
def BuildShortcutModel(): ...
def CreateAction(actionID: str, widget: PyQt5.QtWidgets.QWidget, icon: Incomplete | None = ..., text: Incomplete | None = ..., enabled: bool = ...) -> PyQt5.QtWidgets.QAction | None: ...
def GenerateActionID(name: str) -> str: ...
def GetActionID(contextName: str, actionName: str) -> str | None: ...
def GetFullActionName(actionID: str) -> str | None: ...
def GetFullKeyEventName(keyEventID: str) -> str | None: ...
def GetKeyEventID(contextName: str, keyEventName: str) -> str | None: ...
def GetKeyEventNameForShortcut(contextName: str, shortcut: str) -> str: ...
def GetShortcutForAction(actionNameOrID: str) -> str | None: ...
def GetShortcutForKeyEvent(keyEventID: str) -> str | None: ...
def HandleKeyEvent(widget: PyQt5.QtWidgets.QWidget, keyEvent: PyQt5.QtGui.QKeyEvent) -> bool: ...
def IsShortcutRegisteredForAction(actionContext: str, shortcut: str) -> bool: ...
def IsShortcutRegisteredForClass(className: str, shortcut: str) -> bool: ...
def LoadShortcuts(): ...
def RegisterAction(actionID: str, name: str, shortcut: str | None, callback: types.FunctionType | types.MethodType): ...
def RegisterActions(contextName: str, actions: dict): ...
def RegisterKeyEvent(className: str, keyEventID: str, name: str, shortcut: str, pressCallback: typing.Optional[typing.Callable] = ..., releaseCallback: typing.Optional[typing.Callable] = ..., data: Incomplete | None = ...): ...
def UnregisterAction(actionID: str): ...
def UnregisterKeyEvent(keyEventID: str): ...
def UpdateAction(managedAction: ManagedAction): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import ClassVar, Set, Tuple

class PolicyHelpButton(ToolbarButton):
    _ErrorPixmap: ClassVar[None] = ...
    _ErrorRolloverPixmap: ClassVar[None] = ...
    _NormalPixmap: ClassVar[None] = ...
    _RolloverPixmap: ClassVar[None] = ...
    _WarningPixmap: ClassVar[None] = ...
    _WarningRolloverPixmap: ClassVar[None] = ...
    aboutToShow: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget) -> None: ...
    def _PolicyHelpButton__on_mousePressEvent(self, event): ...
    def getHelpText(self): ...
    def getHelpTitle(self): ...
    def getHelpType(self): ...
    def getHelpURL(self): ...
    def isHelpAvailable(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class SliderBase:
    def __init__(self, range: Incomplete | None = ..., center: Incomplete | None = ..., axisExponent: Incomplete | None = ..., gradient: Incomplete | None = ..., integer: Incomplete | None = ...) -> None: ...
    def _SliderBase__computeAutoAxisExponent(self): ...
    def _SliderBase__drawLabelText(self, painter, value, text, centerLine_y, textPen, labelBounds): ...
    def _SliderBase__measureLabelBounds(self, value, text): ...
    def _clearLabelsCache(self): ...
    def _doDrag(self, windowLocalX): ...
    def _doPaint(self, p, palette): ...
    def _endDrag(self, windowLocalX): ...
    def _getToggleComponentEnabled(self): ...
    def _isInDrag(self): ...
    def _toggleComponent(self): ...
    def getReadOnly(self): ...
    def getValue(self): ...
    def isPreselectionActive(self): ...
    def normalizedValueToValue(self, normValue): ...
    def normalizedValueToWindowPosition(self, normValue): ...
    def setAxisExponent(self, exponent): ...
    def setCenter(self, centerVal): ...
    def setColor(self, c): ...
    def setGradient(self, gradientName): ...
    def setHasFocus(self, hasFocus): ...
    def setInteger(self, isInt): ...
    def setRange(self, val1, val2): ...
    def setReadOnly(self, readOnly, disableComponentToggle: Incomplete | None = ...): ...
    def setValue(self, value): ...
    def valueToNormalizedValue(self, value): ...
    def valueToWindowPosition(self, value): ...
    def windowPositionToNormalizedValue(self, pos): ...
    def windowPositionToValue(self, pos, applyLabelSnapping: bool = ...): ...

class SliderWidget(PyQt5.QtWidgets.QWidget, SliderBase):
    toggleComponent: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, fontScale: Incomplete | None = ..., **kwargs) -> None: ...
    def _displayChanged(self): ...
    def _toggleComponent(self): ...
    def _valueChanged(self, value, final): ...
    def enterEvent(self, ev): ...
    def leaveEvent(self, ev): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def mouseReleaseEvent(self, ev): ...
    def paintEvent(self, ev): ...
    def resizeEvent(self, ev): ...
    def sizeHint(self): ...
    def sizePolicy(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
from UI4.FormMaster.NodeActionDelegate.BaseNodeActionDelegate import BaseNodeActionDelegate as BaseNodeActionDelegate
from _typeshed import Incomplete
from typing import Set, Tuple

def RegisterActionDelegate(nodeType, delegate): ...
def UpdateContextMenuWithDelegates(menu, node: NodegraphAPI.Node): ...
def UpdateWrenchMenuWithDelegates(menu, node: NodegraphAPI.Node, hints: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import PyFnGeolib
import PyFnGeolibProducers
import typing
from LookFileBakeAPI.Exceptions import LookFileBakeException as LookFileBakeException
from _typeshed import Incomplete
from typing import Set, Tuple

def CheckRootLocations(rootLocations: typing.Iterable[str], op: PyFnGeolib.GeolibRuntimeOp, rootLocationProducers: Incomplete | None = ...): ...
def FindSharedLodGroupLocations(rootLocations, origProducer) -> dict: ...
def GetLookFileProducerRootId(producer: PyFnGeolibProducers.GeometryProducer) -> str: ...
def GetProducerFromOp(op: PyFnGeolib.GeolibRuntimeOp) -> PyFnGeolibProducers.GeometryProducer: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.CollectAndSelect as CollectAndSelect
import PyFnAttribute as FnAttribute
import UI4.Util.IconManager as IconManager
import QT4FormWidgets.InputWidgets as InputWidgets
import UI4.Widgets.MessageBox as MessageBox
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyCEL.CanonicalCELEntry
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4.FormMaster
import UI4.Widgets.SortablePanel
import Utils as Utils
from QT4Widgets.MenuButton import MenuButton as MenuButton
from QT4Widgets.StretchBox import StretchBox as StretchBox
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from UI4.Util.ScenegraphLocation import GetNodesCreatingSceneGraphLocations as GetNodesCreatingSceneGraphLocations
from UI4.Widgets.CelResultsWidget import CelResultsWidget as CelResultsWidget, CelResultsWindow as CelResultsWindow
from UI4.Widgets.ComboBoxNoWheel import ComboBoxNoWheel as ComboBoxNoWheel
from UI4.Widgets.RolloverPixmap import RolloverPixmap as RolloverPixmap
from UI4.Widgets.SortablePanel import ParameterExpressionPanel as ParameterExpressionPanel, SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CelEditorFormWidget(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    _CelEditorFormWidget__typeDict: ClassVar[dict] = ...
    _CelEditorFormWidget__typeTitle: ClassVar[dict] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _CelEditorFormWidget__addMenuCallback(self, actionText): ...
    def _CelEditorFormWidget__allowNewPanels(self): ...
    def _CelEditorFormWidget__appendScenegraphSelection(self): ...
    def _CelEditorFormWidget__buildValueFromPanels(self): ...
    def _CelEditorFormWidget__calcCelAndLoc(self, index, useThisStatement): ...
    def _CelEditorFormWidget__confirmAndGetLastPathsPanel(self): ...
    def _CelEditorFormWidget__copyCelStatementAsText(self): ...
    def _CelEditorFormWidget__fillCollectFMenu(self, menu): ...
    def _CelEditorFormWidget__getCollectionStatement(self, locationPath, collectionName): ...
    def _CelEditorFormWidget__getStringParameterPolicy(self, fullParameterName: str | None) -> UI4.FormMaster.BaseParameterPolicy | None: ...
    def _CelEditorFormWidget__getValidDroppedNode(self, mimeData): ...
    def _CelEditorFormWidget__handleScenegraphLocationContextParameterPolicyChange(self, valuePolicyEvent: QT4FormWidgets.ValuePolicy.ValuePolicyEvent): ...
    def _CelEditorFormWidget__on_findAndSelectAction_triggered(self): ...
    def _CelEditorFormWidget__pasteCelStatementAsText(self): ...
    def _CelEditorFormWidget__replaceWithScenegraphSelection(self): ...
    def _CelEditorFormWidget__setLabel(self): ...
    def _participatesInLabelAlignment(self): ...
    def addButtonCheckDragEvent(self, event): ...
    def addButtonDropEvent(self, event): ...
    def buildAddMenu(self, menu): ...
    def collectAndDisplayResults(self, index: int = ..., useThisStatement: Incomplete | None = ...): ...
    def doMenuExp(self): ...
    def event(self, e): ...
    def findAndSelectInScenegraph(self, index: int = ..., useThisStatement: Incomplete | None = ..., replace: bool = ...): ...
    def getCollectionName(self) -> str: ...
    def getScenegraphLocationContext(self) -> str: ...
    def getScenegraphSelection(self): ...
    def panelDeleted(self, index): ...
    def panelValueChanged(self, index): ...
    def updatePanels(self): ...

class CelStatementPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    class AddRemoveExprButton(RolloverPixmap, PyQt5.QtWidgets.QPushButton):
        def __init__(self, parent) -> None: ...
        def isPlus(self): ...
        def setPlus(self, value): ...
    _CelStatementPanel__displayToIndex: ClassVar[dict] = ...
    _CelStatementPanel__displayToOp: ClassVar[dict] = ...
    _CelStatementPanel__opToDisplay: ClassVar[dict] = ...
    k: ClassVar[str] = ...
    v: ClassVar[PyCEL.CanonicalCELEntry.OpType] = ...
    def __init__(self, parent, name, value, argdict: Incomplete | None = ...) -> None: ...
    def _CelStatementPanel__collectAndDisplayResultsOfPanel(self): ...
    def _CelStatementPanel__findAndSelectPanel(self): ...
    def _CelStatementPanel__modeboxChangeCallback(self, value): ...
    def _CelStatementPanel__valueExprButtonClicked(self): ...
    def _CelStatementPanel__valueExprChangedCallback(self): ...
    def buildEntry(self, data, entryType): ...
    def getContentArea(self): ...
    def getFindMenu(self): ...
    def getScenegraphLocationContext(self): ...
    def hideValueExpression(self): ...
    def setIndex(self, index): ...
    def setLocked(self, value): ...
    def showValueExpression(self, exprValue: str = ...): ...

class CollectionsStatementPanel(PathListStatementPanel):
    class CollectionSelectionDialog(PyQt5.QtWidgets.QDialog):
        def __init__(self, parent, possiblelist, alreadylist) -> None: ...
        def _CollectionSelectionDialog__itemSelectionChanged(self): ...
        def _CollectionSelectionDialog__okClicked(self): ...
        def _CollectionSelectionDialog__updateFilter(self, text): ...
        def getResults(self): ...
    def __init__(self, parent, value: Incomplete | None = ...) -> None: ...
    def _CollectionsStatementPanel__addCollectionsFromSelection(self, selection): ...
    def _CollectionsStatementPanel__addGlobalCollectionsCallback(self): ...
    def _CollectionsStatementPanel__addScenegraphSelectionCallback(self): ...
    def _CollectionsStatementPanel__findAndSelectItemsCallback(self): ...
    def _CollectionsStatementPanel__getExistingPaths(self): ...
    def actionMenuAboutToShow(self): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def event(self, e): ...
    def getMinLines(self): ...
    def getValue(self, onlySelected: bool = ..., includeBaseValue: bool = ...): ...
    def processDialogResults(self, results, sendUpdate: bool = ...): ...

class CustomStatementPanel(CelStatementPanel):
    def __init__(self, parent, value: Incomplete | None = ...) -> None: ...
    def _CustomStatementPanel__changedCallback(self): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def getValue(self): ...

class MenuShiftFilter(PyQt5.QtCore.QObject):
    def __init__(self, menu, action) -> None: ...
    def _MenuShiftFilter__aboutToShow(self): ...
    def _MenuShiftFilter__setLabelState(self, state): ...
    def eventFilter(self, receiver, event): ...

class PathListStatementPanel(CelStatementPanel):
    class PathItem(PyQt5.QtWidgets.QTreeWidgetItem):
        def clearMessage(self): ...
        def setErrorMessage(self, message): ...
        def setWarningMessage(self, message): ...
    def __init__(self, parent, name, value: Incomplete | None = ..., argdict: Incomplete | None = ...) -> None: ...
    def _PathListStatementPanel__actionMenuAboutToShow(self): ...
    def _PathListStatementPanel__contextMenuCallback(self, point): ...
    def actionMenuAboutToShow(self): ...
    def copySelectedPathsCallback(self): ...
    def getActionMenu(self): ...
    def getMinLines(self): ...
    def getScenegraphSelection(self): ...
    def getValueTreeWidget(self): ...
    def removeSelectedPathsCallback(self): ...
    def selectAll(self): ...
    def sendChange(self): ...
    def setLocked(self, value): ...
    def updateLabel(self): ...
    def zoomBoxClicked(self): ...

class PathsStatementPanel(PathListStatementPanel):
    class PathListExtendedDialog(PyQt5.QtWidgets.QDialog):
        def __init__(self, paths) -> None: ...
        def getPaths(self): ...
    def __init__(self, parent, value: Incomplete | None = ..., argdict: Incomplete | None = ...) -> None: ...
    def _PathsStatementPanel__getPaths(self): ...
    def _PathsStatementPanel__showExtendedView(self): ...
    def actionMenuAboutToShow(self): ...
    def addScenegraphSelection(self, sendUpdate: bool = ..., selection: Incomplete | None = ...): ...
    def added(self): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def event(self, e): ...
    def getValue(self): ...
    def keyPressEvent(self, event: PyQt5.QtGui.QKeyEvent): ...
    def removeScenegraphSelection(self): ...
    def selectSelectedPathsInScenegraph(self): ...
    def update(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.ArrayItemEntry as ArrayItemEntry
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.FWidget import FBoxLayout as FBoxLayout, FButton as FButton, FDisclosureTriangle as FDisclosureTriangle, FLabel as FLabel, FLockIcon as FLockIcon, FMenu as FMenu, FPixmap as FPixmap, FSpacer as FSpacer, FStateBadge as FStateBadge, FSvgIcon as FSvgIcon, FToggleStateBadge as FToggleStateBadge, FWidget as FWidget
from QT4FormWidgets.FormWidget import AlignChildLabelWidths as AlignChildLabelWidths, AlignLeftControlWidths as AlignLeftControlWidths, FormWidget as FormWidget, ScrubbingStates as ScrubbingStates
from QT4FormWidgets.InputWidgets import InputLineEdit as InputLineEdit
from QT4FormWidgets.MultiStateBadge import MultiStateBadge as MultiStateBadge, ToggleStateBadge as ToggleStateBadge, ToggleValuePolicyState as ToggleValuePolicyState
from QT4FormWidgets.NumberFormWidget import CreateSensitivityMenu as CreateSensitivityMenu, FormatNumber as FormatNumber, NumberFormWidget as NumberFormWidget
from QT4FormWidgets.StringFormWidget import StringFormWidget as StringFormWidget
from QT4FormWidgets.ValuePolicy import ValuePolicyEvent as ValuePolicyEvent
from typing import Set, Tuple

class ArrayFormWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ArrayFormWidget__doSizeEdit(self): ...
    def _ArrayFormWidget__doSliderChange(self, value): ...
    def _ArrayFormWidget__doSliderEdit(self): ...
    def _ArrayFormWidget__doValueEdit(self): ...
    def _ArrayFormWidget__freezeEntries(self): ...
    def _ArrayFormWidget__isInline(self): ...
    def _ArrayFormWidget__syncArrayTopology(self, forced): ...
    def _ArrayFormWidget__syncArrayValues(self): ...
    def _ArrayFormWidget__updateNavigation(self): ...
    def _buildControlWidget(self, controlLayout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _createEntryWidget(self): ...
    def _createRowWidget(self, parent): ...
    def _freeze(self): ...
    def _lockChanged(self, state): ...
    def _popdownCreated(self, popdown): ...
    def _thaw(self): ...
    def showPopdown(self, value): ...
    def valueChangedEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import NodegraphAPI_cmodule as NodegraphAPI_cmodule
from typing import Set, Tuple

def GetAttributes(_node): ...
def GetPortAttributes(node: NodegraphAPI.Node, port: NodegraphAPI.Port) -> dict: ...
def NewNode(_node): ...
def SetAttributes(_node, attrs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PackageSuperToolAPI.BaseNode as BaseNode
import PackageSuperToolAPI.NodeUtils as NodeUtils
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from UI4.Widgets.LightingToolsLayer.LightingToolsUtils import GafferThreeListWatcher as GafferThreeListWatcher
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class EditMask:
    kHere: ClassVar[int] = ...
    kNone: ClassVar[int] = ...
    kNowhere: ClassVar[int] = ...
    kUpstream: ClassVar[int] = ...

class GafferButton(PyQt5.QtWidgets.QPushButton):
    kDimmedTextColor: ClassVar[str] = ...
    kHoverTextColor: ClassVar[str] = ...
    kIconSize: ClassVar[PyQt5.QtCore.QSize] = ...
    kNormalTextColor: ClassVar[str] = ...
    def __init__(self, gafferName: str, parent: Incomplete | None = ...) -> None: ...
    def getGafferNodeName(self) -> str: ...
    def getMasks(self) -> None: ...
    def isDimmed(self) -> bool: ...
    def setDimmed(self, isDimmed): ...
    def setMasks(self, lineMask: int, editMask: int): ...

class LightingToolsGafferComboBox(PyQt5.QtWidgets.QWidget):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _LightingToolsGafferComboBox__createDropdownButton(self): ...
    def _LightingToolsGafferComboBox__createDropdownMenu(self): ...
    def _LightingToolsGafferComboBox__onDropdownButtonPressed(self): ...
    def _LightingToolsGafferComboBox__onGafferListUpdated(self, gafferList: list[str]): ...
    def _LightingToolsGafferComboBox__onGafferSelected(self, gafferName: str): ...
    def _LightingToolsGafferComboBox__onNodeLocked(self): ...
    def _LightingToolsGafferComboBox__onNodegraphChanged(self): ...
    def _LightingToolsGafferComboBox__setGafferMasks(self, action: PyQt5.QtWidgets.QAction, lineMask: int, editMask: int, enableDimming: bool): ...
    def _LightingToolsGafferComboBox__setSelectedGafferNodeName(self, selectedGafferNodeName: str): ...
    def _LightingToolsGafferComboBox__updateDropdownButton(self, editMask: int): ...
    def _LightingToolsGafferComboBox__updateGafferHistory(self): ...
    def cycleSelectedGafferNode(self, delta: int = ...): ...
    def getGafferNodeName(self) -> str: ...
    def setSelectedLocations(self, locations: list[str]): ...

class LineMask:
    kIcon: ClassVar[int] = ...
    kLowerLine: ClassVar[int] = ...
    kNone: ClassVar[int] = ...
    kUpperLine: ClassVar[int] = ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI
from Nodes3DAPI.TerminalOpDelegates.TerminalOpDelegate import TerminalOpDelegate as TerminalOpDelegate
from typing import Set, Tuple

class ExampleTerminalOpDelegate(TerminalOpDelegate):
    def __init__(self) -> None: ...
    def appendOp(self, op, txn, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState): ...
    def reset(self): ...
    def update(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodeGraphView as NodeGraphView
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class NodePopupMenu(PyQt5.QtWidgets.QMenu):
    def __init__(self, node: NodegraphAPI.Node, port: NodegraphAPI.Port, *args) -> None: ...
    def _NodePopupMenu__doActions(self): ...
    def _NodePopupMenu__doFlipbookNode(self, *args): ...
    def _NodePopupMenu__doGenerateAndCueOutlineFile(self): ...
    def _NodePopupMenu__doGenerateOutlineFile(self): ...
    def _NodePopupMenu__doParameters(self): ...
    def _NodePopupMenu__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _NodePopupMenu__regenerateThumbnail(self): ...
    def _NodePopupMenu__toggleThumbnail(self): ...

class PortRenameWidget(PyQt5.QtWidgets.QLineEdit):
    _baseStyle: ClassVar[str] = ...
    _textEndPadding: ClassVar[int] = ...
    _warningStyle: ClassVar[str] = ...
    def __init__(self, parent, port: NodegraphAPI.Port, coords) -> None: ...
    def _PortRenameWidget__acceptChanges(self): ...
    def _PortRenameWidget__getExternalPort(self): ...
    def _PortRenameWidget__isInputSidebar(self): ...
    def _PortRenameWidget__nameConflicts(self, node: NodegraphAPI.Node, newName): ...
    def _PortRenameWidget__renamePort(self, newName): ...
    def _PortRenameWidget__resizeToContents(self, text): ...
    def _PortRenameWidget__textEdited(self, text): ...
    def focusOutEvent(self, _event: Incomplete | None = ...): ...
    def setLeafNameSelected(self): ...
    def show(self): ...
    def sideBarKey(self): ...

class ShadingPortPopupMenu(PyQt5.QtWidgets.QMenu):
    def __init__(self, port: NodegraphAPI.Port, parent, portCoords) -> None: ...
    def _ShadingPortPopupMenu__buildJumpActions(self): ...
    def _ShadingPortPopupMenu__deletePort(self): ...
    def _ShadingPortPopupMenu__isInputPort(self): ...
    def _ShadingPortPopupMenu__jump(self): ...
    def _ShadingPortPopupMenu__rename(self): ...

class _PageState:
    def __init__(self, dataStr) -> None: ...
    def _PageState__getPathString(self, path): ...
    def _PageState__getStateString(self, state): ...
    def asDataString(self): ...
    def getPathsFromPortName(self, portName): ...
    def set(self, fullPortName, state: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Widgets as QT4Widgets
from QT4Widgets.CustomMenu import CustomMenu as CustomMenu
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from QT4FormWidgets.StringFormWidget import StringFormWidget
from UI4.FormMaster.Editors.ShadingNetworkPopupButton import ShadingNetworkPopupButton as ShadingNetworkPopupButton
from typing import Set, Tuple

class NetworkMaterialSpliceNodeName(StringFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _NetworkMaterialSpliceNodeName__getNetworkAttr(self): ...
    def _NetworkMaterialSpliceNodeName__nodePortChosen(self, nodeName, portType, portName): ...
    def _buildControlWidget(self, layout): ...

class ShadingNetworkNodesAttributeGroupWidget(GroupFormWidget):
    def _ShadingNetworkNodesAttributeGroupWidget__getNetworkAttr(self): ...
    def _buildControlWidget(self, layout): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import BandSelectionLayer as BandSelectionLayer, LinkConnectionLayer as LinkConnectionLayer, StructuredPortsNodeLinkConnectionLayer as StructuredPortsNodeLinkConnectionLayer, TransientLayer as TransientLayer
from UI4.Tabs.NodeGraphTab.Layers.BookmarkJumpMenuLayer import BookmarkJumpMenuLayer as BookmarkJumpMenuLayer
from UI4.Tabs.NodeGraphTab.Layers.CustomMenuLayer import CustomMenuLayer as CustomMenuLayer
from UI4.Tabs.NodeGraphTab.Layers.DragAndDropLayer import DragAndDropLayer as DragAndDropLayer
from UI4.Tabs.NodeGraphTab.Layers.FloatingNodeLayer import FloatingNodeLayer as FloatingNodeLayer
from UI4.Tabs.NodeGraphTab.Layers.GroupInteractionLayer import GroupInteractionLayer as GroupInteractionLayer
from UI4.Tabs.NodeGraphTab.Layers.LinkInteractionLayer import LinkInteractionLayer as LinkInteractionLayer
from UI4.Tabs.NodeGraphTab.Layers.MenuLayer import MenuLayer as MenuLayer
from UI4.Tabs.NodeGraphTab.Layers.MergeNodeInteractionLayer import MergeNodeInteractionLayer as MergeNodeInteractionLayer
from UI4.Tabs.NodeGraphTab.Layers.NetworkMaterialNodeInteractionLayer import NetworkMaterialNodeInteractionLayer as NetworkMaterialNodeInteractionLayer
from UI4.Tabs.NodeGraphTab.Layers.NodeCreationMenuLayer import NodeCreationMenuLayer as NodeCreationMenuLayer
from UI4.Tabs.NodeGraphTab.Layers.NodeDrawingLayer import NodeDrawingLayer as NodeDrawingLayer
from UI4.Tabs.NodeGraphTab.Layers.NodeGraphViewDrawingLayer import NodeGraphViewDrawingLayer as NodeGraphViewDrawingLayer
from UI4.Tabs.NodeGraphTab.Layers.NodeGraphViewInteractionLayer import CallbackTransientLayer as CallbackTransientLayer, NodeGraphViewInteractionLayer as NodeGraphViewInteractionLayer, RegisterNodeGraphViewKeyboardShortcuts as RegisterNodeGraphViewKeyboardShortcuts
from UI4.Tabs.NodeGraphTab.Layers.NodeGraphViewStateLayer import NodeGraphViewStateLayer as NodeGraphViewStateLayer
from UI4.Tabs.NodeGraphTab.Layers.NodeInteractionLayer import NodeInteractionLayer as NodeInteractionLayer
from UI4.Tabs.NodeGraphTab.Layers.NodeOverlayLayer import DrawNodeNameOverlay as DrawNodeNameOverlay, NodeOverlayLayer as NodeOverlayLayer
from UI4.Tabs.NodeGraphTab.Layers.OffscreenFlagDisplayLayer import OffscreenFlagDisplayLayer as OffscreenFlagDisplayLayer
from UI4.Tabs.NodeGraphTab.Layers.PortInteractionLayer import PortInteractionLayer as PortInteractionLayer
from UI4.Tabs.NodeGraphTab.Layers.StickyNoteInteractionLayer import StickyNoteInteractionLayer as StickyNoteInteractionLayer
from UI4.Tabs.NodeGraphTab.Layers.StructuredPortsNodeInteractionLayer import StructuredPortsNodeInteractionLayer as StructuredPortsNodeInteractionLayer
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4Widgets.WidgetUtils as WidgetUtils
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LabeledToolbarButton(PyQt5.QtWidgets.QWidget):
    class _ClickLabel(PyQt5.QtWidgets.QLabel):
        clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def mousePressEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    toggled: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, label: str, parent: PyQt5.QtWidgets.QWidget | None, normalPixmap: PyQt5.QtGui.QPixmap, disabledPixmap: Incomplete | None = ..., rolloverPixmap: Incomplete | None = ..., onPixmap: Incomplete | None = ..., sizeFromPixmap: bool = ..., isToggle: bool = ..., disabledRolloverPixmap: Incomplete | None = ..., onRolloverPixmap: Incomplete | None = ..., errorPixmap: Incomplete | None = ..., errorRolloverPixmap: Incomplete | None = ..., clickAction: Incomplete | None = ..., buttonType: str = ...) -> None: ...
    def isOn(self) -> bool: ...
    def setOn(self, on: bool): ...

class ToolbarButton(PyQt5.QtWidgets.QPushButton):
    mousePressEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    rightClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, toolTip: str, parent: PyQt5.QtWidgets.QWidget | None, normalPixmap: PyQt5.QtGui.QPixmap, disabledPixmap: Incomplete | None = ..., rolloverPixmap: Incomplete | None = ..., onPixmap: Incomplete | None = ..., sizeFromPixmap: bool = ..., isToggle: bool = ..., disabledRolloverPixmap: Incomplete | None = ..., onRolloverPixmap: Incomplete | None = ..., errorPixmap: Incomplete | None = ..., errorRolloverPixmap: Incomplete | None = ..., clickAction: Incomplete | None = ..., buttonType: str = ...) -> None: ...
    def _ToolbarButton__actionToggled(self): ...
    def disabledPixmap(self) -> PyQt5.QtGui.QPixmap | None: ...
    def disabledRolloverPixmap(self) -> PyQt5.QtGui.QPixmap | None: ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def errorPixmap(self) -> PyQt5.QtGui.QPixmap | None: ...
    def errorRolloverPixmap(self) -> PyQt5.QtGui.QPixmap | None: ...
    def getButtonType(self) -> str: ...
    def isEnabled(self) -> bool: ...
    def isError(self) -> bool: ...
    def isOn(self) -> bool: ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def mousePressEvent(self, mouseEvent: PyQt5.QtGui.QMouseEvent): ...
    def normalPixmap(self) -> PyQt5.QtGui.QPixmap: ...
    def onPixmap(self) -> PyQt5.QtGui.QPixmap | None: ...
    def onRolloverPixmap(self) -> PyQt5.QtGui.QPixmap | None: ...
    def press(self): ...
    def release(self): ...
    def rolloverPixmap(self) -> PyQt5.QtGui.QPixmap | None: ...
    def setButtonType(self, buttonType: str): ...
    def setDisabled(self, disabled: bool): ...
    def setDisabledPixmap(self, p: PyQt5.QtGui.QPixmap | None): ...
    def setDisabledRolloverPixmap(self, p: PyQt5.QtGui.QPixmap | None): ...
    def setEnabled(self, enabled: bool): ...
    def setError(self, error: bool, toolTip: Incomplete | None = ...): ...
    def setErrorPixmap(self, p: PyQt5.QtGui.QPixmap | None): ...
    def setErrorRolloverPixmap(self, p: PyQt5.QtGui.QPixmap | None): ...
    def setMenu(self, menu): ...
    def setNormalPixmap(self, p: PyQt5.QtGui.QPixmap): ...
    def setOn(self, on: bool): ...
    def setOnPixmap(self, p: PyQt5.QtGui.QPixmap | None): ...
    def setOnRolloverPixmap(self, p: PyQt5.QtGui.QPixmap | None): ...
    def setRolloverPixmap(self, p: PyQt5.QtGui.QPixmap | None): ...
    def toggle(self): ...
    def triggerAction(self): ...
    def update(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import SceneGraphViewColumn
import abc
import typing
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ViewLink(abc.ABC):
    _abc_impl: ClassVar[_abc_data] = ...
    __abstractmethods__: ClassVar[frozenset] = ...
    def addOrUpdateLocation(self, handle, topLevelHandle): ...
    def addOrUpdateTopLevelLocation(self, topLevelHandle): ...
    def allowMultipleSelection(self) -> bool: ...
    def clearExpandedLocationsRegistry(self, clearCurrent: bool = ...): ...
    def collapseLocation(self, handle, topLevelHandle): ...
    def evaluateFilterRules(self, handle: Incomplete | None = ..., topLevelHandle: Incomplete | None = ...): ...
    def expandLocation(self, handle, topLevelHandle): ...
    def frozenWhenHidden(self) -> bool: ...
    def getAllLocations(self): ...
    def getChildLocations(self, locationPath, topLevelLocationPath, visibleOnly: bool = ..., allDescendants: bool = ...): ...
    def getOverrideNodeAndParameterName(self, locationPath: str, attributeName: str) -> None: ...
    def getSelectedLocations(self): ...
    def getUpdateSuppressor(self): ...
    def getWidget(self): ...
    def isLocationExpanded(self, handle, topLevelHandle) -> bool: ...
    def removeLocation(self, handle, topLevelHandle): ...
    def removeTopLevelLocation(self, topLevelHandle): ...
    def resetModel(self): ...
    def saveExpandedLocations(self): ...
    def scrollToLocation(self, handle: SceneGraphHandle, topLevelHandle: SceneGraphHandle): ...
    def selectChildLocations(self, replaceSelection: bool = ...): ...
    def selectLocations(self, locations, replaceSelection: bool = ...): ...
    def selectParentLocations(self, replaceSelection: bool = ...): ...
    def setAboutToDragCallback(self, callback): ...
    def setAllowMultipleSelection(self, allowMultipleSelection: bool): ...
    def setAttributeDataChildren(self, handle: SceneGraphHandle, topLevelHandle: SceneGraphHandle, attributeDataChildren): ...
    def setColumnTitles(self, columnTitleInfo: list[SceneGraphViewColumn.SceneGraphColumnTitle]): ...
    def setColumnWidths(self, columnWidths): ...
    def setContextMenuEventCallback(self, callback): ...
    def setDragMoveEventCallback(self, callback: typing.Callable): ...
    def setDropEventCallback(self, callback: typing.Callable): ...
    def setExpandsOnDoubleClick(self, expandsOnDoubleClick: bool): ...
    def setFrozenWhenHidden(self, frozenWhenHidden: bool = ...): ...
    def setKeyPressEventCallback(self, callback): ...
    def setOverrideParameterRequestCallback(self, callback: typing.Callable): ...
    def setSelectionChangedCallback(self, callback): ...
    def setSelectionState(self, topLevelLocationPath, locationPath, selected): ...
    def sortChildrenUnderLocation(self, handle: SceneGraphHandle, topLevelHandle: SceneGraphHandle): ...
    def sortTopLevelLocations(self): ...
    def updateItemDelegates(self): ...
    def updateLocationIcons(self, handle, topLevelHandle): ...
    def updateSelection(self, selectedLocations, deselectedLocations): ...
    def updateViewport(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class SortableListWidget(PyQt5.QtWidgets.QListWidget):
    aboutToDrag: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    contextMenuEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dragEnterEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dragMoveEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    dropEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    focusInEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    itemHitTest: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    keyPressEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    mouseMoveEventSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    reorderItemSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    reorderItemsSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    selectionChangedSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _SortableListWidget__findToIndex(self, event): ...
    def _SortableListWidget__startDrag(self): ...
    def _SortableListWidget__updateDragHilightBar(self, event): ...
    def contextMenuEvent(self, event): ...
    def customEvent(self, event): ...
    def dragEnterEvent(self, event): ...
    def dragLeaveEvent(self, event): ...
    def dragMoveEvent(self, event): ...
    def dropEvent(self, event): ...
    def focusInEvent(self, event): ...
    def getFullHeight(self): ...
    def getFullWidth(self): ...
    def isDraggable(self): ...
    def isItemDraggable(self, item): ...
    def isSorting(self): ...
    def keyPressEvent(self, event): ...
    def mouseMoveEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def setDraggable(self, state): ...
    def setMultipleDragEnabled(self, state): ...
    def setPixmapHitTestEnabled(self, state): ...
    def sizeHint(self): ...
    def sort(self, ascending: bool = ...): ...

class SortableListWidgetItem(PyQt5.QtWidgets.QListWidgetItem):
    def __init__(self, listbox, text, pixmap: Incomplete | None = ..., data: Incomplete | None = ...) -> None: ...
    def _SortableListWidgetItem__measurePixmaps(self): ...
    def calcSizeHint(self): ...
    def getHiliteColor(self): ...
    def getItemData(self): ...
    def getLabelColor(self): ...
    def getPixmapSize(self): ...
    def getPixmaps(self): ...
    def hitTest(self, x, y): ...
    def setHiliteColor(self, color): ...
    def setItemData(self, data): ...
    def setLabelColor(self, color): ...
    def setPixmap(self, pixmap): ...
    def setPixmaps(self, pixmaps): ...

class SortableListWidgetItemDelegate(PyQt5.QtWidgets.QItemDelegate):
    def paint(self, painter, option, index): ...
    def sizeHint(self, option, index): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class CrashFileSelectorDialog(PyQt5.QtWidgets.QDialog):
    class CrashFileItem(PyQt5.QtWidgets.QTreeWidgetItem):
        def __init__(self, crashDict, *args) -> None: ...
        def getCrashDict(self): ...
    def __init__(self, crashData, parent: Incomplete | None = ...) -> None: ...
    def _CrashFileSelectorDialog__compareCrashFileWithOriginal(self, crashDict): ...
    def _CrashFileSelectorDialog__makeStatString(self, filestat): ...
    def _CrashFileSelectorDialog__on_dialogButtonBox_clicked(self, button): ...
    def accept(self): ...
    def closeEvent(self, event: PyQt5.QtWidgets.QCloseEvent): ...
    def getCrashFile(self): ...
    def getSourceFile(self): ...
    def loadSource(self): ...
    def quitRequested(self) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from . import ArrayItemEntry as ArrayItemEntry, Conditional as Conditional, ExpressionEditDialog as ExpressionEditDialog, FWidget as FWidget, FixableBoxLayout as FixableBoxLayout, FormClose as FormClose, FormWidgetTools as FormWidgetTools, HintUtils as HintUtils, InputWidgets as InputWidgets, Manifest as Manifest, MenuGroupFormWidget as MenuGroupFormWidget, MenuUtils as MenuUtils, MultiStateBadge as MultiStateBadge, OpenState as OpenState, PaintingUtils as PaintingUtils, PolicyMimeData as PolicyMimeData, StateChangeAction as StateChangeAction, TabGroupFormWidget as TabGroupFormWidget, ValueAdjustment as ValueAdjustment, ValuePolicy as ValuePolicy, WideEditDialog as WideEditDialog
from QT4FormWidgets.ArrayFormWidget import ArrayFormWidget as ArrayFormWidget
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from QT4FormWidgets.CapsuleFormWidget import CapsuleFormWidget as CapsuleFormWidget
from QT4FormWidgets.CheckBoxFormWidget import CheckBoxFormWidget as CheckBoxFormWidget
from QT4FormWidgets.Conditional import ConditionalVisibilityOpBase as ConditionalVisibilityOpBase, ParseStandardConditionalHints as ParseStandardConditionalHints, RegisterConditionalVisibilityOp as RegisterConditionalVisibilityOp
from QT4FormWidgets.ExternalEditorDialog import EditPolicy as EditPolicy, ExternalEditorDialog as ExternalEditorDialog
from QT4FormWidgets.FilterablePopupFormWidget import FilterablePopupFormWidget as FilterablePopupFormWidget
from QT4FormWidgets.FormDialog import FormDialog as FormDialog
from QT4FormWidgets.FormWidget import AlignChildLabelWidths as AlignChildLabelWidths, AlignLeftControlWidths as AlignLeftControlWidths, FormWidget as FormWidget, ScrubbingStates as ScrubbingStates
from QT4FormWidgets.FormWidgetLabel import FormWidgetLabel as FormWidgetLabel
from QT4FormWidgets.FormWidgetTools import DeepPolicyCompare as DeepPolicyCompare, GetTopologyDifferences as GetTopologyDifferences, PaintFormWidgetFrame as PaintFormWidgetFrame
from QT4FormWidgets.GroupFormWidget import GroupFormWidget as GroupFormWidget
from QT4FormWidgets.MultiFormWidget import MultiFormWidget as MultiFormWidget
from QT4FormWidgets.NullFormWidget import NullFormWidget as NullFormWidget
from QT4FormWidgets.NumberFormWidget import CreateSensitivityMenu as CreateSensitivityMenu, FormatNumber as FormatNumber, NumberFormWidget as NumberFormWidget
from QT4FormWidgets.PopupFormWidget import BooleanFormWidget as BooleanFormWidget, MappingPopupFormWidget as MappingPopupFormWidget, PopupFormWidget as PopupFormWidget
from QT4FormWidgets.PythonValuePolicy import PythonDictValuePolicy as PythonDictValuePolicy, PythonGroupPolicy as PythonGroupPolicy, PythonValuePolicy as PythonValuePolicy
from QT4FormWidgets.StringFormWidget import StringFormWidget as StringFormWidget
from QT4FormWidgets.TextFormWidget import TextFormWidget as TextFormWidget
from QT4FormWidgets.ValuePolicy import AbstractValuePolicy as AbstractValuePolicy, ValuePolicyEvent as ValuePolicyEvent, ValuePolicyProxy as ValuePolicyProxy
from QT4FormWidgets.ValuePolicyAdapter import CreateValuePolicyAdapter as CreateValuePolicyAdapter, CreateValuePolicyAdapterMap as CreateValuePolicyAdapterMap, FlattenValuePolicyAdapterMap as FlattenValuePolicyAdapterMap, ValuePolicyAdapter as ValuePolicyAdapter
from QT4FormWidgets.WidgetFactory import GetDefaultWidgetFactory as GetDefaultWidgetFactory, WidgetFactory as WidgetFactory
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
from typing import Set, Tuple

class PageEntry:
    def __init__(self, name, fullname, childnames, subpages) -> None: ...

def ProcessPageEntryList(entries): ...
def SortByPage(names, getPageFnc, includeUnpaged: bool = ...): ...
